#ifndef IDECIDEDTOCONVERTALLTHECHARACTERSINCHARMAPUT8
#define IDECIDEDTOCONVERTALLTHECHARACTERSINCHARMAPUT8

#include <robin_hood.h>
#include <string>
#include "defines.h"

FORCE_INLINE std::string codePointToUTF8(int codePoint) {
    std::string result;

    if (codePoint < 0x80) {
        result.push_back(static_cast<char>(codePoint));
    } else if (codePoint < 0x800) {
        result.push_back(static_cast<char>(0xC0 | (codePoint >> 6)));
        result.push_back(static_cast<char>(0x80 | (codePoint & 0x3F)));
    } else if (codePoint < 0x10000) {
        result.push_back(static_cast<char>(0xE0 | (codePoint >> 12)));
        result.push_back(static_cast<char>(0x80 | ((codePoint >> 6) & 0x3F)));
        result.push_back(static_cast<char>(0x80 | (codePoint & 0x3F)));
    } else {
        result.push_back(static_cast<char>(0xF0 | (codePoint >> 18)));
        result.push_back(static_cast<char>(0x80 | ((codePoint >> 12) & 0x3F)));
        result.push_back(static_cast<char>(0x80 | ((codePoint >> 6) & 0x3F)));
        result.push_back(static_cast<char>(0x80 | (codePoint & 0x3F)));
    }
    return result;
}
static robin_hood::unordered_flat_map<int, std::string> accent_mapping;

static robin_hood::unordered_flat_map<int, std::string> initializeCharMap() {
    robin_hood::unordered_flat_map<int, std::string> charMap;
    charMap[0x00c0] = codePointToUTF8(0x0061); //    # Á --> a
    charMap[0x00c1] = codePointToUTF8(0x0061); //    # Â --> a
    charMap[0x00c2] = codePointToUTF8(0x0061); //    # Ã --> a
    charMap[0x00c3] = codePointToUTF8(0x0061); //    # Ä --> a
    charMap[0x00c4] = codePointToUTF8(0x0061); //    # Å --> a
    charMap[0x00c5] = codePointToUTF8(0x0061); //    # Æ --> æ
    charMap[0x00c6] = codePointToUTF8(0x00e6); //    # Ç --> c
    charMap[0x00c7] = codePointToUTF8(0x0063); //    # È --> e
    charMap[0x00c8] = codePointToUTF8(0x0065); //    # É --> e
    charMap[0x00c9] = codePointToUTF8(0x0065); //    # Ê --> e
    charMap[0x00ca] = codePointToUTF8(0x0065); //    # Ë --> e
    charMap[0x00cb] = codePointToUTF8(0x0065); //    # Ì --> i
    charMap[0x00cc] = codePointToUTF8(0x0069); //    # Í --> i
    charMap[0x00cd] = codePointToUTF8(0x0069); //    # Î --> i
    charMap[0x00ce] = codePointToUTF8(0x0069); //    # Ï --> i
    charMap[0x00cf] = codePointToUTF8(0x0069); //    # Ð --> ð
    charMap[0x00d0] = codePointToUTF8(0x00f0); //    # Ñ --> n
    charMap[0x00d1] = codePointToUTF8(0x006e); //    # Ò --> o
    charMap[0x00d2] = codePointToUTF8(0x006f); //    # Ó --> o
    charMap[0x00d3] = codePointToUTF8(0x006f); //    # Ô --> o
    charMap[0x00d4] = codePointToUTF8(0x006f); //    # Õ --> o
    charMap[0x00d5] = codePointToUTF8(0x006f); //    # Ö --> o
    charMap[0x00d6] = codePointToUTF8(0x006f); //    # Ø --> ø
    charMap[0x00d8] = codePointToUTF8(0x00f8); //    # Ù --> u
    charMap[0x00d9] = codePointToUTF8(0x0075); //    # Ú --> u
    charMap[0x00da] = codePointToUTF8(0x0075); //    # Û --> u
    charMap[0x00db] = codePointToUTF8(0x0075); //    # Ü --> u
    charMap[0x00dc] = codePointToUTF8(0x0075); //    # Ý --> y
    charMap[0x00dd] = codePointToUTF8(0x0079); //    # Þ --> þ
    charMap[0x00de] = codePointToUTF8(0x00fe); //    # à --> a
    charMap[0x00e0] = codePointToUTF8(0x0061); //    # á --> a
    charMap[0x00e1] = codePointToUTF8(0x0061); //    # â --> a
    charMap[0x00e2] = codePointToUTF8(0x0061); //    # ã --> a
    charMap[0x00e3] = codePointToUTF8(0x0061); //    # ä --> a
    charMap[0x00e4] = codePointToUTF8(0x0061); //    # å --> a
    charMap[0x00e5] = codePointToUTF8(0x0061); //    # ç --> c
    charMap[0x00e7] = codePointToUTF8(0x0063); //    # è --> e
    charMap[0x00e8] = codePointToUTF8(0x0065); //    # é --> e
    charMap[0x00e9] = codePointToUTF8(0x0065); //    # ê --> e
    charMap[0x00ea] = codePointToUTF8(0x0065); //    # ë --> e
    charMap[0x00eb] = codePointToUTF8(0x0065); //    # ì --> i
    charMap[0x00ec] = codePointToUTF8(0x0069); //    # í --> i
    charMap[0x00ed] = codePointToUTF8(0x0069); //    # î --> i
    charMap[0x00ee] = codePointToUTF8(0x0069); //    # ï --> i
    charMap[0x00ef] = codePointToUTF8(0x0069); //    # ñ --> n
    charMap[0x00f1] = codePointToUTF8(0x006e); //    # ò --> o
    charMap[0x00f2] = codePointToUTF8(0x006f); //    # ó --> o
    charMap[0x00f3] = codePointToUTF8(0x006f); //    # ô --> o
    charMap[0x00f4] = codePointToUTF8(0x006f); //    # õ --> o
    charMap[0x00f5] = codePointToUTF8(0x006f); //    # ö --> o
    charMap[0x00f6] = codePointToUTF8(0x006f); //    # ù --> u
    charMap[0x00f9] = codePointToUTF8(0x0075); //    # ú --> u
    charMap[0x00fa] = codePointToUTF8(0x0075); //    # û --> u
    charMap[0x00fb] = codePointToUTF8(0x0075); //    # ü --> u
    charMap[0x00fc] = codePointToUTF8(0x0075); //    # ý --> y
    charMap[0x00fd] = codePointToUTF8(0x0079); //    # ÿ --> y
    charMap[0x00ff] = codePointToUTF8(0x0079); //    # Ā --> a
    charMap[0x0100] = codePointToUTF8(0x0061); //    # ā --> a
    charMap[0x0101] = codePointToUTF8(0x0061); //    # Ă --> a
    charMap[0x0102] = codePointToUTF8(0x0061); //    # ă --> a
    charMap[0x0103] = codePointToUTF8(0x0061); //    # Ą --> a
    charMap[0x0104] = codePointToUTF8(0x0061); //    # ą --> a
    charMap[0x0105] = codePointToUTF8(0x0061); //    # Ć --> c
    charMap[0x0106] = codePointToUTF8(0x0063); //    # ć --> c
    charMap[0x0107] = codePointToUTF8(0x0063); //    # Ĉ --> c
    charMap[0x0108] = codePointToUTF8(0x0063); //    # ĉ --> c
    charMap[0x0109] = codePointToUTF8(0x0063); //    # Ċ --> c
    charMap[0x010a] = codePointToUTF8(0x0063); //    # ċ --> c
    charMap[0x010b] = codePointToUTF8(0x0063); //    # Č --> c
    charMap[0x010c] = codePointToUTF8(0x0063); //    # č --> c
    charMap[0x010d] = codePointToUTF8(0x0063); //    # Ď --> d
    charMap[0x010e] = codePointToUTF8(0x0064); //    # ď --> d
    charMap[0x010f] = codePointToUTF8(0x0064); //    # Đ --> đ
    charMap[0x0110] = codePointToUTF8(0x0111); //    # Ē --> e
    charMap[0x0112] = codePointToUTF8(0x0065); //    # ē --> e
    charMap[0x0113] = codePointToUTF8(0x0065); //    # Ĕ --> e
    charMap[0x0114] = codePointToUTF8(0x0065); //    # ĕ --> e
    charMap[0x0115] = codePointToUTF8(0x0065); //    # Ė --> e
    charMap[0x0116] = codePointToUTF8(0x0065); //    # ė --> e
    charMap[0x0117] = codePointToUTF8(0x0065); //    # Ę --> e
    charMap[0x0118] = codePointToUTF8(0x0065); //    # ę --> e
    charMap[0x0119] = codePointToUTF8(0x0065); //    # Ě --> e
    charMap[0x011a] = codePointToUTF8(0x0065); //    # ě --> e
    charMap[0x011b] = codePointToUTF8(0x0065); //    # Ĝ --> g
    charMap[0x011c] = codePointToUTF8(0x0067); //    # ĝ --> g
    charMap[0x011d] = codePointToUTF8(0x0067); //    # Ğ --> g
    charMap[0x011e] = codePointToUTF8(0x0067); //    # ğ --> g
    charMap[0x011f] = codePointToUTF8(0x0067); //    # Ġ --> g
    charMap[0x0120] = codePointToUTF8(0x0067); //    # ġ --> g
    charMap[0x0121] = codePointToUTF8(0x0067); //    # Ģ --> g
    charMap[0x0122] = codePointToUTF8(0x0067); //    # ģ --> g
    charMap[0x0123] = codePointToUTF8(0x0067); //    # Ĥ --> h
    charMap[0x0124] = codePointToUTF8(0x0068); //    # ĥ --> h
    charMap[0x0125] = codePointToUTF8(0x0068); //    # Ħ --> ħ
    charMap[0x0126] = codePointToUTF8(0x0127); //    # Ĩ --> i
    charMap[0x0128] = codePointToUTF8(0x0069); //    # ĩ --> i
    charMap[0x0129] = codePointToUTF8(0x0069); //    # Ī --> i
    charMap[0x012a] = codePointToUTF8(0x0069); //    # ī --> i
    charMap[0x012b] = codePointToUTF8(0x0069); //    # Ĭ --> i
    charMap[0x012c] = codePointToUTF8(0x0069); //    # ĭ --> i
    charMap[0x012d] = codePointToUTF8(0x0069); //    # Į --> i
    charMap[0x012e] = codePointToUTF8(0x0069); //    # į --> i
    charMap[0x012f] = codePointToUTF8(0x0069); //    # İ --> i
    charMap[0x0130] = codePointToUTF8(0x0069); //    # Ĳ --> ĳ
    charMap[0x0132] = codePointToUTF8(0x0133); //    # Ĵ --> j
    charMap[0x0134] = codePointToUTF8(0x006a); //    # ĵ --> j
    charMap[0x0135] = codePointToUTF8(0x006a); //    # Ķ --> k
    charMap[0x0136] = codePointToUTF8(0x006b); //    # ķ --> k
    charMap[0x0137] = codePointToUTF8(0x006b); //    # Ĺ --> l
    charMap[0x0139] = codePointToUTF8(0x006c); //    # ĺ --> l
    charMap[0x013a] = codePointToUTF8(0x006c); //    # Ļ --> l
    charMap[0x013b] = codePointToUTF8(0x006c); //    # ļ --> l
    charMap[0x013c] = codePointToUTF8(0x006c); //    # Ľ --> l
    charMap[0x013d] = codePointToUTF8(0x006c); //    # ľ --> l
    charMap[0x013e] = codePointToUTF8(0x006c); //    # Ŀ --> ŀ
    charMap[0x013f] = codePointToUTF8(0x0140); //    # Ł --> ł
    charMap[0x0141] = codePointToUTF8(0x0142); //    # Ń --> n
    charMap[0x0143] = codePointToUTF8(0x006e); //    # ń --> n
    charMap[0x0144] = codePointToUTF8(0x006e); //    # Ņ --> n
    charMap[0x0145] = codePointToUTF8(0x006e); //    # ņ --> n
    charMap[0x0146] = codePointToUTF8(0x006e); //    # Ň --> n
    charMap[0x0147] = codePointToUTF8(0x006e); //    # ň --> n
    charMap[0x0148] = codePointToUTF8(0x006e); //    # Ŋ --> ŋ
    charMap[0x014a] = codePointToUTF8(0x014b); //    # Ō --> o
    charMap[0x014c] = codePointToUTF8(0x006f); //    # ō --> o
    charMap[0x014d] = codePointToUTF8(0x006f); //    # Ŏ --> o
    charMap[0x014e] = codePointToUTF8(0x006f); //    # ŏ --> o
    charMap[0x014f] = codePointToUTF8(0x006f); //    # Ő --> o
    charMap[0x0150] = codePointToUTF8(0x006f); //    # ő --> o
    charMap[0x0151] = codePointToUTF8(0x006f); //    # Œ --> œ
    charMap[0x0152] = codePointToUTF8(0x0153); //    # Ŕ --> r
    charMap[0x0154] = codePointToUTF8(0x0072); //    # ŕ --> r
    charMap[0x0155] = codePointToUTF8(0x0072); //    # Ŗ --> r
    charMap[0x0156] = codePointToUTF8(0x0072); //    # ŗ --> r
    charMap[0x0157] = codePointToUTF8(0x0072); //    # Ř --> r
    charMap[0x0158] = codePointToUTF8(0x0072); //    # ř --> r
    charMap[0x0159] = codePointToUTF8(0x0072); //    # Ś --> s
    charMap[0x015a] = codePointToUTF8(0x0073); //    # ś --> s
    charMap[0x015b] = codePointToUTF8(0x0073); //    # Ŝ --> s
    charMap[0x015c] = codePointToUTF8(0x0073); //    # ŝ --> s
    charMap[0x015d] = codePointToUTF8(0x0073); //    # Ş --> s
    charMap[0x015e] = codePointToUTF8(0x0073); //    # ş --> s
    charMap[0x015f] = codePointToUTF8(0x0073); //    # Š --> s
    charMap[0x0160] = codePointToUTF8(0x0073); //    # š --> s
    charMap[0x0161] = codePointToUTF8(0x0073); //    # Ţ --> t
    charMap[0x0162] = codePointToUTF8(0x0074); //    # ţ --> t
    charMap[0x0163] = codePointToUTF8(0x0074); //    # Ť --> t
    charMap[0x0164] = codePointToUTF8(0x0074); //    # ť --> t
    charMap[0x0165] = codePointToUTF8(0x0074); //    # Ŧ --> ŧ
    charMap[0x0166] = codePointToUTF8(0x0167); //    # Ũ --> u
    charMap[0x0168] = codePointToUTF8(0x0075); //    # ũ --> u
    charMap[0x0169] = codePointToUTF8(0x0075); //    # Ū --> u
    charMap[0x016a] = codePointToUTF8(0x0075); //    # ū --> u
    charMap[0x016b] = codePointToUTF8(0x0075); //    # Ŭ --> u
    charMap[0x016c] = codePointToUTF8(0x0075); //    # ŭ --> u
    charMap[0x016d] = codePointToUTF8(0x0075); //    # Ů --> u
    charMap[0x016e] = codePointToUTF8(0x0075); //    # ů --> u
    charMap[0x016f] = codePointToUTF8(0x0075); //    # Ű --> u
    charMap[0x0170] = codePointToUTF8(0x0075); //    # ű --> u
    charMap[0x0171] = codePointToUTF8(0x0075); //    # Ų --> u
    charMap[0x0172] = codePointToUTF8(0x0075); //    # ų --> u
    charMap[0x0173] = codePointToUTF8(0x0075); //    # Ŵ --> w
    charMap[0x0174] = codePointToUTF8(0x0077); //    # ŵ --> w
    charMap[0x0175] = codePointToUTF8(0x0077); //    # Ŷ --> y
    charMap[0x0176] = codePointToUTF8(0x0079); //    # ŷ --> y
    charMap[0x0177] = codePointToUTF8(0x0079); //    # Ÿ --> y
    charMap[0x0178] = codePointToUTF8(0x0079); //    # Ź --> z
    charMap[0x0179] = codePointToUTF8(0x007a); //    # ź --> z
    charMap[0x017a] = codePointToUTF8(0x007a); //    # Ż --> z
    charMap[0x017b] = codePointToUTF8(0x007a); //    # ż --> z
    charMap[0x017c] = codePointToUTF8(0x007a); //    # Ž --> z
    charMap[0x017d] = codePointToUTF8(0x007a); //    # ž --> z
    charMap[0x017e] = codePointToUTF8(0x007a); //    # Ɓ --> ɓ
    charMap[0x0181] = codePointToUTF8(0x0253); //    # Ƃ --> ƃ
    charMap[0x0182] = codePointToUTF8(0x0183); //    # Ƅ --> ƅ
    charMap[0x0184] = codePointToUTF8(0x0185); //    # Ɔ --> ɔ
    charMap[0x0186] = codePointToUTF8(0x0254); //    # Ƈ --> ƈ
    charMap[0x0187] = codePointToUTF8(0x0188); //    # Ɖ --> ɖ
    charMap[0x0189] = codePointToUTF8(0x0256); //    # Ɗ --> ɗ
    charMap[0x018a] = codePointToUTF8(0x0257); //    # Ƌ --> ƌ
    charMap[0x018b] = codePointToUTF8(0x018c); //    # Ǝ --> ǝ
    charMap[0x018e] = codePointToUTF8(0x01dd); //    # Ə --> ə
    charMap[0x018f] = codePointToUTF8(0x0259); //    # Ɛ --> ɛ
    charMap[0x0190] = codePointToUTF8(0x025b); //    # Ƒ --> ƒ
    charMap[0x0191] = codePointToUTF8(0x0192); //    # Ɠ --> ɠ
    charMap[0x0193] = codePointToUTF8(0x0260); //    # Ɣ --> ɣ
    charMap[0x0194] = codePointToUTF8(0x0263); //    # Ɩ --> ɩ
    charMap[0x0196] = codePointToUTF8(0x0269); //    # Ɨ --> ɨ
    charMap[0x0197] = codePointToUTF8(0x0268); //    # Ƙ --> ƙ
    charMap[0x0198] = codePointToUTF8(0x0199); //    # Ɯ --> ɯ
    charMap[0x019c] = codePointToUTF8(0x026f); //    # Ɲ --> ɲ
    charMap[0x019d] = codePointToUTF8(0x0272); //    # Ɵ --> ɵ
    charMap[0x019f] = codePointToUTF8(0x0275); //    # Ơ --> o
    charMap[0x01a0] = codePointToUTF8(0x006f); //    # ơ --> o
    charMap[0x01a1] = codePointToUTF8(0x006f); //    # Ƣ --> ƣ
    charMap[0x01a2] = codePointToUTF8(0x01a3); //    # Ƥ --> ƥ
    charMap[0x01a4] = codePointToUTF8(0x01a5); //    # Ʀ --> ʀ
    charMap[0x01a6] = codePointToUTF8(0x0280); //    # Ƨ --> ƨ
    charMap[0x01a7] = codePointToUTF8(0x01a8); //    # Ʃ --> ʃ
    charMap[0x01a9] = codePointToUTF8(0x0283); //    # Ƭ --> ƭ
    charMap[0x01ac] = codePointToUTF8(0x01ad); //    # Ʈ --> ʈ
    charMap[0x01ae] = codePointToUTF8(0x0288); //    # Ư --> u
    charMap[0x01af] = codePointToUTF8(0x0075); //    # ư --> u
    charMap[0x01b0] = codePointToUTF8(0x0075); //    # Ʊ --> ʊ
    charMap[0x01b1] = codePointToUTF8(0x028a); //    # Ʋ --> ʋ
    charMap[0x01b2] = codePointToUTF8(0x028b); //    # Ƴ --> ƴ
    charMap[0x01b3] = codePointToUTF8(0x01b4); //    # Ƶ --> ƶ
    charMap[0x01b5] = codePointToUTF8(0x01b6); //    # Ʒ --> ʒ
    charMap[0x01b7] = codePointToUTF8(0x0292); //    # Ƹ --> ƹ
    charMap[0x01b8] = codePointToUTF8(0x01b9); //    # Ƽ --> ƽ
    charMap[0x01bc] = codePointToUTF8(0x01bd); //    # Ǆ --> ǆ
    charMap[0x01c4] = codePointToUTF8(0x01c6); //    # ǅ --> ǆ
    charMap[0x01c5] = codePointToUTF8(0x01c6); //    # Ǉ --> ǉ
    charMap[0x01c7] = codePointToUTF8(0x01c9); //    # ǈ --> ǉ
    charMap[0x01c8] = codePointToUTF8(0x01c9); //    # Ǌ --> ǌ
    charMap[0x01ca] = codePointToUTF8(0x01cc); //    # ǋ --> ǌ
    charMap[0x01cb] = codePointToUTF8(0x01cc); //    # Ǎ --> a
    charMap[0x01cd] = codePointToUTF8(0x0061); //    # ǎ --> a
    charMap[0x01ce] = codePointToUTF8(0x0061); //    # Ǐ --> i
    charMap[0x01cf] = codePointToUTF8(0x0069); //    # ǐ --> i
    charMap[0x01d0] = codePointToUTF8(0x0069); //    # Ǒ --> o
    charMap[0x01d1] = codePointToUTF8(0x006f); //    # ǒ --> o
    charMap[0x01d2] = codePointToUTF8(0x006f); //    # Ǔ --> u
    charMap[0x01d3] = codePointToUTF8(0x0075); //    # ǔ --> u
    charMap[0x01d4] = codePointToUTF8(0x0075); //    # Ǖ --> u
    charMap[0x01d5] = codePointToUTF8(0x0075); //    # ǖ --> u
    charMap[0x01d6] = codePointToUTF8(0x0075); //    # Ǘ --> u
    charMap[0x01d7] = codePointToUTF8(0x0075); //    # ǘ --> u
    charMap[0x01d8] = codePointToUTF8(0x0075); //    # Ǚ --> u
    charMap[0x01d9] = codePointToUTF8(0x0075); //    # ǚ --> u
    charMap[0x01da] = codePointToUTF8(0x0075); //    # Ǜ --> u
    charMap[0x01db] = codePointToUTF8(0x0075); //    # ǜ --> u
    charMap[0x01dc] = codePointToUTF8(0x0075); //    # Ǟ --> a
    charMap[0x01de] = codePointToUTF8(0x0061); //    # ǟ --> a
    charMap[0x01df] = codePointToUTF8(0x0061); //    # Ǡ --> a
    charMap[0x01e0] = codePointToUTF8(0x0061); //    # ǡ --> a
    charMap[0x01e1] = codePointToUTF8(0x0061); //    # Ǣ --> æ
    charMap[0x01e2] = codePointToUTF8(0x00e6); //    # ǣ --> æ
    charMap[0x01e3] = codePointToUTF8(0x00e6); //    # Ǥ --> ǥ
    charMap[0x01e4] = codePointToUTF8(0x01e5); //    # Ǧ --> g
    charMap[0x01e6] = codePointToUTF8(0x0067); //    # ǧ --> g
    charMap[0x01e7] = codePointToUTF8(0x0067); //    # Ǩ --> k
    charMap[0x01e8] = codePointToUTF8(0x006b); //    # ǩ --> k
    charMap[0x01e9] = codePointToUTF8(0x006b); //    # Ǫ --> o
    charMap[0x01ea] = codePointToUTF8(0x006f); //    # ǫ --> o
    charMap[0x01eb] = codePointToUTF8(0x006f); //    # Ǭ --> o
    charMap[0x01ec] = codePointToUTF8(0x006f); //    # ǭ --> o
    charMap[0x01ed] = codePointToUTF8(0x006f); //    # Ǯ --> ʒ
    charMap[0x01ee] = codePointToUTF8(0x0292); //    # ǯ --> ʒ
    charMap[0x01ef] = codePointToUTF8(0x0292); //    # ǰ --> j
    charMap[0x01f0] = codePointToUTF8(0x006a); //    # Ǳ --> ǳ
    charMap[0x01f1] = codePointToUTF8(0x01f3); //    # ǲ --> ǳ
    charMap[0x01f2] = codePointToUTF8(0x01f3); //    # Ǵ --> g
    charMap[0x01f4] = codePointToUTF8(0x0067); //    # ǵ --> g
    charMap[0x01f5] = codePointToUTF8(0x0067); //    # Ƕ --> ƕ
    charMap[0x01f6] = codePointToUTF8(0x0195); //    # Ƿ --> ƿ
    charMap[0x01f7] = codePointToUTF8(0x01bf); //    # Ǹ --> n
    charMap[0x01f8] = codePointToUTF8(0x006e); //    # ǹ --> n
    charMap[0x01f9] = codePointToUTF8(0x006e); //    # Ǻ --> a
    charMap[0x01fa] = codePointToUTF8(0x0061); //    # ǻ --> a
    charMap[0x01fb] = codePointToUTF8(0x0061); //    # Ǽ --> æ
    charMap[0x01fc] = codePointToUTF8(0x00e6); //    # ǽ --> æ
    charMap[0x01fd] = codePointToUTF8(0x00e6); //    # Ǿ --> ø
    charMap[0x01fe] = codePointToUTF8(0x00f8); //    # ǿ --> ø
    charMap[0x01ff] = codePointToUTF8(0x00f8); //    # Ȁ --> a
    charMap[0x0200] = codePointToUTF8(0x0061); //    # ȁ --> a
    charMap[0x0201] = codePointToUTF8(0x0061); //    # Ȃ --> a
    charMap[0x0202] = codePointToUTF8(0x0061); //    # ȃ --> a
    charMap[0x0203] = codePointToUTF8(0x0061); //    # Ȅ --> e
    charMap[0x0204] = codePointToUTF8(0x0065); //    # ȅ --> e
    charMap[0x0205] = codePointToUTF8(0x0065); //    # Ȇ --> e
    charMap[0x0206] = codePointToUTF8(0x0065); //    # ȇ --> e
    charMap[0x0207] = codePointToUTF8(0x0065); //    # Ȉ --> i
    charMap[0x0208] = codePointToUTF8(0x0069); //    # ȉ --> i
    charMap[0x0209] = codePointToUTF8(0x0069); //    # Ȋ --> i
    charMap[0x020a] = codePointToUTF8(0x0069); //    # ȋ --> i
    charMap[0x020b] = codePointToUTF8(0x0069); //    # Ȍ --> o
    charMap[0x020c] = codePointToUTF8(0x006f); //    # ȍ --> o
    charMap[0x020d] = codePointToUTF8(0x006f); //    # Ȏ --> o
    charMap[0x020e] = codePointToUTF8(0x006f); //    # ȏ --> o
    charMap[0x020f] = codePointToUTF8(0x006f); //    # Ȑ --> r
    charMap[0x0210] = codePointToUTF8(0x0072); //    # ȑ --> r
    charMap[0x0211] = codePointToUTF8(0x0072); //    # Ȓ --> r
    charMap[0x0212] = codePointToUTF8(0x0072); //    # ȓ --> r
    charMap[0x0213] = codePointToUTF8(0x0072); //    # Ȕ --> u
    charMap[0x0214] = codePointToUTF8(0x0075); //    # ȕ --> u
    charMap[0x0215] = codePointToUTF8(0x0075); //    # Ȗ --> u
    charMap[0x0216] = codePointToUTF8(0x0075); //    # ȗ --> u
    charMap[0x0217] = codePointToUTF8(0x0075); //    # Ș --> s
    charMap[0x0218] = codePointToUTF8(0x0073); //    # ș --> s
    charMap[0x0219] = codePointToUTF8(0x0073); //    # Ț --> t
    charMap[0x021a] = codePointToUTF8(0x0074); //    # ț --> t
    charMap[0x021b] = codePointToUTF8(0x0074); //    # Ȝ --> ȝ
    charMap[0x021c] = codePointToUTF8(0x021d); //    # Ȟ --> h
    charMap[0x021e] = codePointToUTF8(0x0068); //    # ȟ --> h
    charMap[0x021f] = codePointToUTF8(0x0068); //    # Ƞ --> ƞ
    charMap[0x0220] = codePointToUTF8(0x019e); //    # Ȣ --> ȣ
    charMap[0x0222] = codePointToUTF8(0x0223); //    # Ȥ --> ȥ
    charMap[0x0224] = codePointToUTF8(0x0225); //    # Ȧ --> a
    charMap[0x0226] = codePointToUTF8(0x0061); //    # ȧ --> a
    charMap[0x0227] = codePointToUTF8(0x0061); //    # Ȩ --> e
    charMap[0x0228] = codePointToUTF8(0x0065); //    # ȩ --> e
    charMap[0x0229] = codePointToUTF8(0x0065); //    # Ȫ --> o
    charMap[0x022a] = codePointToUTF8(0x006f); //    # ȫ --> o
    charMap[0x022b] = codePointToUTF8(0x006f); //    # Ȭ --> o
    charMap[0x022c] = codePointToUTF8(0x006f); //    # ȭ --> o
    charMap[0x022d] = codePointToUTF8(0x006f); //    # Ȯ --> o
    charMap[0x022e] = codePointToUTF8(0x006f); //    # ȯ --> o
    charMap[0x022f] = codePointToUTF8(0x006f); //    # Ȱ --> o
    charMap[0x0230] = codePointToUTF8(0x006f); //    # ȱ --> o
    charMap[0x0231] = codePointToUTF8(0x006f); //    # Ȳ --> y
    charMap[0x0232] = codePointToUTF8(0x0079); //    # ȳ --> y
    charMap[0x0233] = codePointToUTF8(0x0079); //    # Ⱥ --> ⱥ
    charMap[0x023a] = codePointToUTF8(0x2c65); //    # Ȼ --> ȼ
    charMap[0x023b] = codePointToUTF8(0x023c); //    # Ƚ --> ƚ
    charMap[0x023d] = codePointToUTF8(0x019a); //    # Ⱦ --> ⱦ
    charMap[0x023e] = codePointToUTF8(0x2c66); //    # Ɂ --> ɂ
    charMap[0x0241] = codePointToUTF8(0x0242); //    # Ƀ --> ƀ
    charMap[0x0243] = codePointToUTF8(0x0180); //    # Ʉ --> ʉ
    charMap[0x0244] = codePointToUTF8(0x0289); //    # Ʌ --> ʌ
    charMap[0x0245] = codePointToUTF8(0x028c); //    # Ɇ --> ɇ
    charMap[0x0246] = codePointToUTF8(0x0247); //    # Ɉ --> ɉ
    charMap[0x0248] = codePointToUTF8(0x0249); //    # Ɋ --> ɋ
    charMap[0x024a] = codePointToUTF8(0x024b); //    # Ɍ --> ɍ
    charMap[0x024c] = codePointToUTF8(0x024d); //    # Ɏ --> ɏ
    charMap[0x024e] = codePointToUTF8(0x024f); //    # Ͱ --> ͱ
    charMap[0x0370] = codePointToUTF8(0x0371); //    # Ͳ --> ͳ
    charMap[0x0372] = codePointToUTF8(0x0373); //    # Ͷ --> ͷ
    charMap[0x0376] = codePointToUTF8(0x0377); //    # Ϳ --> ϳ
    charMap[0x037f] = codePointToUTF8(0x03f3); //    # ΅ --> ¨
    charMap[0x0385] = codePointToUTF8(0x00a8); //    # Ά --> α
    charMap[0x0386] = codePointToUTF8(0x03b1); //    # Έ --> ε
    charMap[0x0388] = codePointToUTF8(0x03b5); //    # Ή --> η
    charMap[0x0389] = codePointToUTF8(0x03b7); //    # Ί --> ι
    charMap[0x038a] = codePointToUTF8(0x03b9); //    # Ό --> ο
    charMap[0x038c] = codePointToUTF8(0x03bf); //    # Ύ --> υ
    charMap[0x038e] = codePointToUTF8(0x03c5); //    # Ώ --> ω
    charMap[0x038f] = codePointToUTF8(0x03c9); //    # ΐ --> ι
    charMap[0x0390] = codePointToUTF8(0x03b9); //    # Α --> α
    charMap[0x0391] = codePointToUTF8(0x03b1); //    # Β --> β
    charMap[0x0392] = codePointToUTF8(0x03b2); //    # Γ --> γ
    charMap[0x0393] = codePointToUTF8(0x03b3); //    # Δ --> δ
    charMap[0x0394] = codePointToUTF8(0x03b4); //    # Ε --> ε
    charMap[0x0395] = codePointToUTF8(0x03b5); //    # Ζ --> ζ
    charMap[0x0396] = codePointToUTF8(0x03b6); //    # Η --> η
    charMap[0x0397] = codePointToUTF8(0x03b7); //    # Θ --> θ
    charMap[0x0398] = codePointToUTF8(0x03b8); //    # Ι --> ι
    charMap[0x0399] = codePointToUTF8(0x03b9); //    # Κ --> κ
    charMap[0x039a] = codePointToUTF8(0x03ba); //    # Λ --> λ
    charMap[0x039b] = codePointToUTF8(0x03bb); //    # Μ --> μ
    charMap[0x039c] = codePointToUTF8(0x03bc); //    # Ν --> ν
    charMap[0x039d] = codePointToUTF8(0x03bd); //    # Ξ --> ξ
    charMap[0x039e] = codePointToUTF8(0x03be); //    # Ο --> ο
    charMap[0x039f] = codePointToUTF8(0x03bf); //    # Π --> π
    charMap[0x03a0] = codePointToUTF8(0x03c0); //    # Ρ --> ρ
    charMap[0x03a1] = codePointToUTF8(0x03c1); //    # Σ --> σ
    charMap[0x03a3] = codePointToUTF8(0x03c3); //    # Τ --> τ
    charMap[0x03a4] = codePointToUTF8(0x03c4); //    # Υ --> υ
    charMap[0x03a5] = codePointToUTF8(0x03c5); //    # Φ --> φ
    charMap[0x03a6] = codePointToUTF8(0x03c6); //    # Χ --> χ
    charMap[0x03a7] = codePointToUTF8(0x03c7); //    # Ψ --> ψ
    charMap[0x03a8] = codePointToUTF8(0x03c8); //    # Ω --> ω
    charMap[0x03a9] = codePointToUTF8(0x03c9); //    # Ϊ --> ι
    charMap[0x03aa] = codePointToUTF8(0x03b9); //    # Ϋ --> υ
    charMap[0x03ab] = codePointToUTF8(0x03c5); //    # ά --> α
    charMap[0x03ac] = codePointToUTF8(0x03b1); //    # έ --> ε
    charMap[0x03ad] = codePointToUTF8(0x03b5); //    # ή --> η
    charMap[0x03ae] = codePointToUTF8(0x03b7); //    # ί --> ι
    charMap[0x03af] = codePointToUTF8(0x03b9); //    # ΰ --> υ
    charMap[0x03b0] = codePointToUTF8(0x03c5); //    # ϊ --> ι
    charMap[0x03ca] = codePointToUTF8(0x03b9); //    # ϋ --> υ
    charMap[0x03cb] = codePointToUTF8(0x03c5); //    # ό --> ο
    charMap[0x03cc] = codePointToUTF8(0x03bf); //    # ύ --> υ
    charMap[0x03cd] = codePointToUTF8(0x03c5); //    # ώ --> ω
    charMap[0x03ce] = codePointToUTF8(0x03c9); //    # Ϗ --> ϗ
    charMap[0x03cf] = codePointToUTF8(0x03d7); //    # ϓ --> ϒ
    charMap[0x03d3] = codePointToUTF8(0x03d2); //    # ϔ --> ϒ
    charMap[0x03d4] = codePointToUTF8(0x03d2); //    # Ϙ --> ϙ
    charMap[0x03d8] = codePointToUTF8(0x03d9); //    # Ϛ --> ϛ
    charMap[0x03da] = codePointToUTF8(0x03db); //    # Ϝ --> ϝ
    charMap[0x03dc] = codePointToUTF8(0x03dd); //    # Ϟ --> ϟ
    charMap[0x03de] = codePointToUTF8(0x03df); //    # Ϡ --> ϡ
    charMap[0x03e0] = codePointToUTF8(0x03e1); //    # Ϣ --> ϣ
    charMap[0x03e2] = codePointToUTF8(0x03e3); //    # Ϥ --> ϥ
    charMap[0x03e4] = codePointToUTF8(0x03e5); //    # Ϧ --> ϧ
    charMap[0x03e6] = codePointToUTF8(0x03e7); //    # Ϩ --> ϩ
    charMap[0x03e8] = codePointToUTF8(0x03e9); //    # Ϫ --> ϫ
    charMap[0x03ea] = codePointToUTF8(0x03eb); //    # Ϭ --> ϭ
    charMap[0x03ec] = codePointToUTF8(0x03ed); //    # Ϯ --> ϯ
    charMap[0x03ee] = codePointToUTF8(0x03ef); //    # ϴ --> θ
    charMap[0x03f4] = codePointToUTF8(0x03b8); //    # Ϸ --> ϸ
    charMap[0x03f7] = codePointToUTF8(0x03f8); //    # Ϲ --> ϲ
    charMap[0x03f9] = codePointToUTF8(0x03f2); //    # Ϻ --> ϻ
    charMap[0x03fa] = codePointToUTF8(0x03fb); //    # Ͻ --> ͻ
    charMap[0x03fd] = codePointToUTF8(0x037b); //    # Ͼ --> ͼ
    charMap[0x03fe] = codePointToUTF8(0x037c); //    # Ͽ --> ͽ
    charMap[0x03ff] = codePointToUTF8(0x037d); //    # Ѐ --> е
    charMap[0x0400] = codePointToUTF8(0x0435); //    # Ё --> е
    charMap[0x0401] = codePointToUTF8(0x0435); //    # Ђ --> ђ
    charMap[0x0402] = codePointToUTF8(0x0452); //    # Ѓ --> г
    charMap[0x0403] = codePointToUTF8(0x0433); //    # Є --> є
    charMap[0x0404] = codePointToUTF8(0x0454); //    # Ѕ --> ѕ
    charMap[0x0405] = codePointToUTF8(0x0455); //    # І --> і
    charMap[0x0406] = codePointToUTF8(0x0456); //    # Ї --> і
    charMap[0x0407] = codePointToUTF8(0x0456); //    # Ј --> ј
    charMap[0x0408] = codePointToUTF8(0x0458); //    # Љ --> љ
    charMap[0x0409] = codePointToUTF8(0x0459); //    # Њ --> њ
    charMap[0x040a] = codePointToUTF8(0x045a); //    # Ћ --> ћ
    charMap[0x040b] = codePointToUTF8(0x045b); //    # Ќ --> к
    charMap[0x040c] = codePointToUTF8(0x043a); //    # Ѝ --> и
    charMap[0x040d] = codePointToUTF8(0x0438); //    # Ў --> у
    charMap[0x040e] = codePointToUTF8(0x0443); //    # Џ --> џ
    charMap[0x040f] = codePointToUTF8(0x045f); //    # А --> а
    charMap[0x0410] = codePointToUTF8(0x0430); //    # Б --> б
    charMap[0x0411] = codePointToUTF8(0x0431); //    # В --> в
    charMap[0x0412] = codePointToUTF8(0x0432); //    # Г --> г
    charMap[0x0413] = codePointToUTF8(0x0433); //    # Д --> д
    charMap[0x0414] = codePointToUTF8(0x0434); //    # Е --> е
    charMap[0x0415] = codePointToUTF8(0x0435); //    # Ж --> ж
    charMap[0x0416] = codePointToUTF8(0x0436); //    # З --> з
    charMap[0x0417] = codePointToUTF8(0x0437); //    # И --> и
    charMap[0x0418] = codePointToUTF8(0x0438); //    # Й --> и
    charMap[0x0419] = codePointToUTF8(0x0438); //    # К --> к
    charMap[0x041a] = codePointToUTF8(0x043a); //    # Л --> л
    charMap[0x041b] = codePointToUTF8(0x043b); //    # М --> м
    charMap[0x041c] = codePointToUTF8(0x043c); //    # Н --> н
    charMap[0x041d] = codePointToUTF8(0x043d); //    # О --> о
    charMap[0x041e] = codePointToUTF8(0x043e); //    # П --> п
    charMap[0x041f] = codePointToUTF8(0x043f); //    # Р --> р
    charMap[0x0420] = codePointToUTF8(0x0440); //    # С --> с
    charMap[0x0421] = codePointToUTF8(0x0441); //    # Т --> т
    charMap[0x0422] = codePointToUTF8(0x0442); //    # У --> у
    charMap[0x0423] = codePointToUTF8(0x0443); //    # Ф --> ф
    charMap[0x0424] = codePointToUTF8(0x0444); //    # Х --> х
    charMap[0x0425] = codePointToUTF8(0x0445); //    # Ц --> ц
    charMap[0x0426] = codePointToUTF8(0x0446); //    # Ч --> ч
    charMap[0x0427] = codePointToUTF8(0x0447); //    # Ш --> ш
    charMap[0x0428] = codePointToUTF8(0x0448); //    # Щ --> щ
    charMap[0x0429] = codePointToUTF8(0x0449); //    # Ъ --> ъ
    charMap[0x042a] = codePointToUTF8(0x044a); //    # Ы --> ы
    charMap[0x042b] = codePointToUTF8(0x044b); //    # Ь --> ь
    charMap[0x042c] = codePointToUTF8(0x044c); //    # Э --> э
    charMap[0x042d] = codePointToUTF8(0x044d); //    # Ю --> ю
    charMap[0x042e] = codePointToUTF8(0x044e); //    # Я --> я
    charMap[0x042f] = codePointToUTF8(0x044f); //    # й --> и
    charMap[0x0439] = codePointToUTF8(0x0438); //    # ѐ --> е
    charMap[0x0450] = codePointToUTF8(0x0435); //    # ё --> е
    charMap[0x0451] = codePointToUTF8(0x0435); //    # ѓ --> г
    charMap[0x0453] = codePointToUTF8(0x0433); //    # ї --> і
    charMap[0x0457] = codePointToUTF8(0x0456); //    # ќ --> к
    charMap[0x045c] = codePointToUTF8(0x043a); //    # ѝ --> и
    charMap[0x045d] = codePointToUTF8(0x0438); //    # ў --> у
    charMap[0x045e] = codePointToUTF8(0x0443); //    # Ѡ --> ѡ
    charMap[0x0460] = codePointToUTF8(0x0461); //    # Ѣ --> ѣ
    charMap[0x0462] = codePointToUTF8(0x0463); //    # Ѥ --> ѥ
    charMap[0x0464] = codePointToUTF8(0x0465); //    # Ѧ --> ѧ
    charMap[0x0466] = codePointToUTF8(0x0467); //    # Ѩ --> ѩ
    charMap[0x0468] = codePointToUTF8(0x0469); //    # Ѫ --> ѫ
    charMap[0x046a] = codePointToUTF8(0x046b); //    # Ѭ --> ѭ
    charMap[0x046c] = codePointToUTF8(0x046d); //    # Ѯ --> ѯ
    charMap[0x046e] = codePointToUTF8(0x046f); //    # Ѱ --> ѱ
    charMap[0x0470] = codePointToUTF8(0x0471); //    # Ѳ --> ѳ
    charMap[0x0472] = codePointToUTF8(0x0473); //    # Ѵ --> ѵ
    charMap[0x0474] = codePointToUTF8(0x0475); //    # Ѷ --> ѵ
    charMap[0x0476] = codePointToUTF8(0x0475); //    # ѷ --> ѵ
    charMap[0x0477] = codePointToUTF8(0x0475); //    # Ѹ --> ѹ
    charMap[0x0478] = codePointToUTF8(0x0479); //    # Ѻ --> ѻ
    charMap[0x047a] = codePointToUTF8(0x047b); //    # Ѽ --> ѽ
    charMap[0x047c] = codePointToUTF8(0x047d); //    # Ѿ --> ѿ
    charMap[0x047e] = codePointToUTF8(0x047f); //    # Ҁ --> ҁ
    charMap[0x0480] = codePointToUTF8(0x0481); //    # Ҋ --> ҋ
    charMap[0x048a] = codePointToUTF8(0x048b); //    # Ҍ --> ҍ
    charMap[0x048c] = codePointToUTF8(0x048d); //    # Ҏ --> ҏ
    charMap[0x048e] = codePointToUTF8(0x048f); //    # Ґ --> ґ
    charMap[0x0490] = codePointToUTF8(0x0491); //    # Ғ --> ғ
    charMap[0x0492] = codePointToUTF8(0x0493); //    # Ҕ --> ҕ
    charMap[0x0494] = codePointToUTF8(0x0495); //    # Җ --> җ
    charMap[0x0496] = codePointToUTF8(0x0497); //    # Ҙ --> ҙ
    charMap[0x0498] = codePointToUTF8(0x0499); //    # Қ --> қ
    charMap[0x049a] = codePointToUTF8(0x049b); //    # Ҝ --> ҝ
    charMap[0x049c] = codePointToUTF8(0x049d); //    # Ҟ --> ҟ
    charMap[0x049e] = codePointToUTF8(0x049f); //    # Ҡ --> ҡ
    charMap[0x04a0] = codePointToUTF8(0x04a1); //    # Ң --> ң
    charMap[0x04a2] = codePointToUTF8(0x04a3); //    # Ҥ --> ҥ
    charMap[0x04a4] = codePointToUTF8(0x04a5); //    # Ҧ --> ҧ
    charMap[0x04a6] = codePointToUTF8(0x04a7); //    # Ҩ --> ҩ
    charMap[0x04a8] = codePointToUTF8(0x04a9); //    # Ҫ --> ҫ
    charMap[0x04aa] = codePointToUTF8(0x04ab); //    # Ҭ --> ҭ
    charMap[0x04ac] = codePointToUTF8(0x04ad); //    # Ү --> ү
    charMap[0x04ae] = codePointToUTF8(0x04af); //    # Ұ --> ұ
    charMap[0x04b0] = codePointToUTF8(0x04b1); //    # Ҳ --> ҳ
    charMap[0x04b2] = codePointToUTF8(0x04b3); //    # Ҵ --> ҵ
    charMap[0x04b4] = codePointToUTF8(0x04b5); //    # Ҷ --> ҷ
    charMap[0x04b6] = codePointToUTF8(0x04b7); //    # Ҹ --> ҹ
    charMap[0x04b8] = codePointToUTF8(0x04b9); //    # Һ --> һ
    charMap[0x04ba] = codePointToUTF8(0x04bb); //    # Ҽ --> ҽ
    charMap[0x04bc] = codePointToUTF8(0x04bd); //    # Ҿ --> ҿ
    charMap[0x04be] = codePointToUTF8(0x04bf); //    # Ӏ --> ӏ
    charMap[0x04c0] = codePointToUTF8(0x04cf); //    # Ӂ --> ж
    charMap[0x04c1] = codePointToUTF8(0x0436); //    # ӂ --> ж
    charMap[0x04c2] = codePointToUTF8(0x0436); //    # Ӄ --> ӄ
    charMap[0x04c3] = codePointToUTF8(0x04c4); //    # Ӆ --> ӆ
    charMap[0x04c5] = codePointToUTF8(0x04c6); //    # Ӈ --> ӈ
    charMap[0x04c7] = codePointToUTF8(0x04c8); //    # Ӊ --> ӊ
    charMap[0x04c9] = codePointToUTF8(0x04ca); //    # Ӌ --> ӌ
    charMap[0x04cb] = codePointToUTF8(0x04cc); //    # Ӎ --> ӎ
    charMap[0x04cd] = codePointToUTF8(0x04ce); //    # Ӑ --> а
    charMap[0x04d0] = codePointToUTF8(0x0430); //    # ӑ --> а
    charMap[0x04d1] = codePointToUTF8(0x0430); //    # Ӓ --> а
    charMap[0x04d2] = codePointToUTF8(0x0430); //    # ӓ --> а
    charMap[0x04d3] = codePointToUTF8(0x0430); //    # Ӕ --> ӕ
    charMap[0x04d4] = codePointToUTF8(0x04d5); //    # Ӗ --> е
    charMap[0x04d6] = codePointToUTF8(0x0435); //    # ӗ --> е
    charMap[0x04d7] = codePointToUTF8(0x0435); //    # Ә --> ә
    charMap[0x04d8] = codePointToUTF8(0x04d9); //    # Ӛ --> ә
    charMap[0x04da] = codePointToUTF8(0x04d9); //    # ӛ --> ә
    charMap[0x04db] = codePointToUTF8(0x04d9); //    # Ӝ --> ж
    charMap[0x04dc] = codePointToUTF8(0x0436); //    # ӝ --> ж
    charMap[0x04dd] = codePointToUTF8(0x0436); //    # Ӟ --> з
    charMap[0x04de] = codePointToUTF8(0x0437); //    # ӟ --> з
    charMap[0x04df] = codePointToUTF8(0x0437); //    # Ӡ --> ӡ
    charMap[0x04e0] = codePointToUTF8(0x04e1); //    # Ӣ --> и
    charMap[0x04e2] = codePointToUTF8(0x0438); //    # ӣ --> и
    charMap[0x04e3] = codePointToUTF8(0x0438); //    # Ӥ --> и
    charMap[0x04e4] = codePointToUTF8(0x0438); //    # ӥ --> и
    charMap[0x04e5] = codePointToUTF8(0x0438); //    # Ӧ --> о
    charMap[0x04e6] = codePointToUTF8(0x043e); //    # ӧ --> о
    charMap[0x04e7] = codePointToUTF8(0x043e); //    # Ө --> ө
    charMap[0x04e8] = codePointToUTF8(0x04e9); //    # Ӫ --> ө
    charMap[0x04ea] = codePointToUTF8(0x04e9); //    # ӫ --> ө
    charMap[0x04eb] = codePointToUTF8(0x04e9); //    # Ӭ --> э
    charMap[0x04ec] = codePointToUTF8(0x044d); //    # ӭ --> э
    charMap[0x04ed] = codePointToUTF8(0x044d); //    # Ӯ --> у
    charMap[0x04ee] = codePointToUTF8(0x0443); //    # ӯ --> у
    charMap[0x04ef] = codePointToUTF8(0x0443); //    # Ӱ --> у
    charMap[0x04f0] = codePointToUTF8(0x0443); //    # ӱ --> у
    charMap[0x04f1] = codePointToUTF8(0x0443); //    # Ӳ --> у
    charMap[0x04f2] = codePointToUTF8(0x0443); //    # ӳ --> у
    charMap[0x04f3] = codePointToUTF8(0x0443); //    # Ӵ --> ч
    charMap[0x04f4] = codePointToUTF8(0x0447); //    # ӵ --> ч
    charMap[0x04f5] = codePointToUTF8(0x0447); //    # Ӷ --> ӷ
    charMap[0x04f6] = codePointToUTF8(0x04f7); //    # Ӹ --> ы
    charMap[0x04f8] = codePointToUTF8(0x044b); //    # ӹ --> ы
    charMap[0x04f9] = codePointToUTF8(0x044b); //    # Ӻ --> ӻ
    charMap[0x04fa] = codePointToUTF8(0x04fb); //    # Ӽ --> ӽ
    charMap[0x04fc] = codePointToUTF8(0x04fd); //    # Ӿ --> ӿ
    charMap[0x04fe] = codePointToUTF8(0x04ff); //    # Ԁ --> ԁ
    charMap[0x0500] = codePointToUTF8(0x0501); //    # Ԃ --> ԃ
    charMap[0x0502] = codePointToUTF8(0x0503); //    # Ԅ --> ԅ
    charMap[0x0504] = codePointToUTF8(0x0505); //    # Ԇ --> ԇ
    charMap[0x0506] = codePointToUTF8(0x0507); //    # Ԉ --> ԉ
    charMap[0x0508] = codePointToUTF8(0x0509); //    # Ԋ --> ԋ
    charMap[0x050a] = codePointToUTF8(0x050b); //    # Ԍ --> ԍ
    charMap[0x050c] = codePointToUTF8(0x050d); //    # Ԏ --> ԏ
    charMap[0x050e] = codePointToUTF8(0x050f); //    # Ԑ --> ԑ
    charMap[0x0510] = codePointToUTF8(0x0511); //    # Ԓ --> ԓ
    charMap[0x0512] = codePointToUTF8(0x0513); //    # Ԕ --> ԕ
    charMap[0x0514] = codePointToUTF8(0x0515); //    # Ԗ --> ԗ
    charMap[0x0516] = codePointToUTF8(0x0517); //    # Ԙ --> ԙ
    charMap[0x0518] = codePointToUTF8(0x0519); //    # Ԛ --> ԛ
    charMap[0x051a] = codePointToUTF8(0x051b); //    # Ԝ --> ԝ
    charMap[0x051c] = codePointToUTF8(0x051d); //    # Ԟ --> ԟ
    charMap[0x051e] = codePointToUTF8(0x051f); //    # Ԡ --> ԡ
    charMap[0x0520] = codePointToUTF8(0x0521); //    # Ԣ --> ԣ
    charMap[0x0522] = codePointToUTF8(0x0523); //    # Ԥ --> ԥ
    charMap[0x0524] = codePointToUTF8(0x0525); //    # Ԧ --> ԧ
    charMap[0x0526] = codePointToUTF8(0x0527); //    # Ԩ --> ԩ
    charMap[0x0528] = codePointToUTF8(0x0529); //    # Ԫ --> ԫ
    charMap[0x052a] = codePointToUTF8(0x052b); //    # Ԭ --> ԭ
    charMap[0x052c] = codePointToUTF8(0x052d); //    # Ԯ --> ԯ
    charMap[0x052e] = codePointToUTF8(0x052f); //    # Ա --> ա
    charMap[0x0531] = codePointToUTF8(0x0561); //    # Բ --> բ
    charMap[0x0532] = codePointToUTF8(0x0562); //    # Գ --> գ
    charMap[0x0533] = codePointToUTF8(0x0563); //    # Դ --> դ
    charMap[0x0534] = codePointToUTF8(0x0564); //    # Ե --> ե
    charMap[0x0535] = codePointToUTF8(0x0565); //    # Զ --> զ
    charMap[0x0536] = codePointToUTF8(0x0566); //    # Է --> է
    charMap[0x0537] = codePointToUTF8(0x0567); //    # Ը --> ը
    charMap[0x0538] = codePointToUTF8(0x0568); //    # Թ --> թ
    charMap[0x0539] = codePointToUTF8(0x0569); //    # Ժ --> ժ
    charMap[0x053a] = codePointToUTF8(0x056a); //    # Ի --> ի
    charMap[0x053b] = codePointToUTF8(0x056b); //    # Լ --> լ
    charMap[0x053c] = codePointToUTF8(0x056c); //    # Խ --> խ
    charMap[0x053d] = codePointToUTF8(0x056d); //    # Ծ --> ծ
    charMap[0x053e] = codePointToUTF8(0x056e); //    # Կ --> կ
    charMap[0x053f] = codePointToUTF8(0x056f); //    # Հ --> հ
    charMap[0x0540] = codePointToUTF8(0x0570); //    # Ձ --> ձ
    charMap[0x0541] = codePointToUTF8(0x0571); //    # Ղ --> ղ
    charMap[0x0542] = codePointToUTF8(0x0572); //    # Ճ --> ճ
    charMap[0x0543] = codePointToUTF8(0x0573); //    # Մ --> մ
    charMap[0x0544] = codePointToUTF8(0x0574); //    # Յ --> յ
    charMap[0x0545] = codePointToUTF8(0x0575); //    # Ն --> ն
    charMap[0x0546] = codePointToUTF8(0x0576); //    # Շ --> շ
    charMap[0x0547] = codePointToUTF8(0x0577); //    # Ո --> ո
    charMap[0x0548] = codePointToUTF8(0x0578); //    # Չ --> չ
    charMap[0x0549] = codePointToUTF8(0x0579); //    # Պ --> պ
    charMap[0x054a] = codePointToUTF8(0x057a); //    # Ջ --> ջ
    charMap[0x054b] = codePointToUTF8(0x057b); //    # Ռ --> ռ
    charMap[0x054c] = codePointToUTF8(0x057c); //    # Ս --> ս
    charMap[0x054d] = codePointToUTF8(0x057d); //    # Վ --> վ
    charMap[0x054e] = codePointToUTF8(0x057e); //    # Տ --> տ
    charMap[0x054f] = codePointToUTF8(0x057f); //    # Ր --> ր
    charMap[0x0550] = codePointToUTF8(0x0580); //    # Ց --> ց
    charMap[0x0551] = codePointToUTF8(0x0581); //    # Ւ --> ւ
    charMap[0x0552] = codePointToUTF8(0x0582); //    # Փ --> փ
    charMap[0x0553] = codePointToUTF8(0x0583); //    # Ք --> ք
    charMap[0x0554] = codePointToUTF8(0x0584); //    # Օ --> օ
    charMap[0x0555] = codePointToUTF8(0x0585); //    # Ֆ --> ֆ
    charMap[0x0556] = codePointToUTF8(0x0586); //    # آ --> ا
    charMap[0x0622] = codePointToUTF8(0x0627); //    # أ --> ا
    charMap[0x0623] = codePointToUTF8(0x0627); //    # ؤ --> و
    charMap[0x0624] = codePointToUTF8(0x0648); //    # إ --> ا
    charMap[0x0625] = codePointToUTF8(0x0627); //    # ئ --> ي
    charMap[0x0626] = codePointToUTF8(0x064a); //    # ۀ --> ە
    charMap[0x06c0] = codePointToUTF8(0x06d5); //    # ۂ --> ہ
    charMap[0x06c2] = codePointToUTF8(0x06c1); //    # ۓ --> ے
    charMap[0x06d3] = codePointToUTF8(0x06d2); //    # ऩ --> न
    charMap[0x0929] = codePointToUTF8(0x0928); //    # ऱ --> र
    charMap[0x0931] = codePointToUTF8(0x0930); //    # ऴ --> ळ
    charMap[0x0934] = codePointToUTF8(0x0933); //    # क़ --> क
    charMap[0x0958] = codePointToUTF8(0x0915); //    # ख़ --> ख
    charMap[0x0959] = codePointToUTF8(0x0916); //    # ग़ --> ग
    charMap[0x095a] = codePointToUTF8(0x0917); //    # ज़ --> ज
    charMap[0x095b] = codePointToUTF8(0x091c); //    # ड़ --> ड
    charMap[0x095c] = codePointToUTF8(0x0921); //    # ढ़ --> ढ
    charMap[0x095d] = codePointToUTF8(0x0922); //    # फ़ --> फ
    charMap[0x095e] = codePointToUTF8(0x092b); //    # य़ --> य
    charMap[0x095f] = codePointToUTF8(0x092f); //    # ড় --> ড
    charMap[0x09dc] = codePointToUTF8(0x09a1); //    # ঢ় --> ঢ
    charMap[0x09dd] = codePointToUTF8(0x09a2); //    # য় --> য
    charMap[0x09df] = codePointToUTF8(0x09af); //    # ਲ਼ --> ਲ
    charMap[0x0a33] = codePointToUTF8(0x0a32); //    # ਸ਼ --> ਸ
    charMap[0x0a36] = codePointToUTF8(0x0a38); //    # ਖ਼ --> ਖ
    charMap[0x0a59] = codePointToUTF8(0x0a16); //    # ਗ਼ --> ਗ
    charMap[0x0a5a] = codePointToUTF8(0x0a17); //    # ਜ਼ --> ਜ
    charMap[0x0a5b] = codePointToUTF8(0x0a1c); //    # ਫ਼ --> ਫ
    charMap[0x0a5e] = codePointToUTF8(0x0a2b); //    # ୈ --> େ
    charMap[0x0b48] = codePointToUTF8(0x0b47); //    # ଡ଼ --> ଡ
    charMap[0x0b5c] = codePointToUTF8(0x0b21); //    # ଢ଼ --> ଢ
    charMap[0x0b5d] = codePointToUTF8(0x0b22); //    # ೀ --> ೕ
    charMap[0x0cc0] = codePointToUTF8(0x0cd5); //    # ೇ --> ೕ
    charMap[0x0cc7] = codePointToUTF8(0x0cd5); //    # ೈ --> ೖ
    charMap[0x0cc8] = codePointToUTF8(0x0cd6); //    # ೊ --> ೂ
    charMap[0x0cca] = codePointToUTF8(0x0cc2); //    # ೋ --> ೂೕ
    charMap[0x0ccb] = codePointToUTF8(0x0cc2); //    # ේ --> ෙ
    charMap[0x0dda] = codePointToUTF8(0x0dd9); //    # ෝ --> ො
    charMap[0x0ddd] = codePointToUTF8(0x0dd9); //    # གྷ --> ག
    charMap[0x0f43] = codePointToUTF8(0x0f42); //    # ཌྷ --> ཌ
    charMap[0x0f4d] = codePointToUTF8(0x0f4c); //    # དྷ --> ད
    charMap[0x0f52] = codePointToUTF8(0x0f51); //    # བྷ --> བ
    charMap[0x0f57] = codePointToUTF8(0x0f56); //    # ཛྷ --> ཛ
    charMap[0x0f5c] = codePointToUTF8(0x0f5b); //    # ཀྵ --> ཀ
    charMap[0x0f69] = codePointToUTF8(0x0f40); //    # ဦ --> ဥ
    charMap[0x1026] = codePointToUTF8(0x1025); //    # Ⴀ --> ⴀ
    charMap[0x10a0] = codePointToUTF8(0x2d00); //    # Ⴁ --> ⴁ
    charMap[0x10a1] = codePointToUTF8(0x2d01); //    # Ⴂ --> ⴂ
    charMap[0x10a2] = codePointToUTF8(0x2d02); //    # Ⴃ --> ⴃ
    charMap[0x10a3] = codePointToUTF8(0x2d03); //    # Ⴄ --> ⴄ
    charMap[0x10a4] = codePointToUTF8(0x2d04); //    # Ⴅ --> ⴅ
    charMap[0x10a5] = codePointToUTF8(0x2d05); //    # Ⴆ --> ⴆ
    charMap[0x10a6] = codePointToUTF8(0x2d06); //    # Ⴇ --> ⴇ
    charMap[0x10a7] = codePointToUTF8(0x2d07); //    # Ⴈ --> ⴈ
    charMap[0x10a8] = codePointToUTF8(0x2d08); //    # Ⴉ --> ⴉ
    charMap[0x10a9] = codePointToUTF8(0x2d09); //    # Ⴊ --> ⴊ
    charMap[0x10aa] = codePointToUTF8(0x2d0a); //    # Ⴋ --> ⴋ
    charMap[0x10ab] = codePointToUTF8(0x2d0b); //    # Ⴌ --> ⴌ
    charMap[0x10ac] = codePointToUTF8(0x2d0c); //    # Ⴍ --> ⴍ
    charMap[0x10ad] = codePointToUTF8(0x2d0d); //    # Ⴎ --> ⴎ
    charMap[0x10ae] = codePointToUTF8(0x2d0e); //    # Ⴏ --> ⴏ
    charMap[0x10af] = codePointToUTF8(0x2d0f); //    # Ⴐ --> ⴐ
    charMap[0x10b0] = codePointToUTF8(0x2d10); //    # Ⴑ --> ⴑ
    charMap[0x10b1] = codePointToUTF8(0x2d11); //    # Ⴒ --> ⴒ
    charMap[0x10b2] = codePointToUTF8(0x2d12); //    # Ⴓ --> ⴓ
    charMap[0x10b3] = codePointToUTF8(0x2d13); //    # Ⴔ --> ⴔ
    charMap[0x10b4] = codePointToUTF8(0x2d14); //    # Ⴕ --> ⴕ
    charMap[0x10b5] = codePointToUTF8(0x2d15); //    # Ⴖ --> ⴖ
    charMap[0x10b6] = codePointToUTF8(0x2d16); //    # Ⴗ --> ⴗ
    charMap[0x10b7] = codePointToUTF8(0x2d17); //    # Ⴘ --> ⴘ
    charMap[0x10b8] = codePointToUTF8(0x2d18); //    # Ⴙ --> ⴙ
    charMap[0x10b9] = codePointToUTF8(0x2d19); //    # Ⴚ --> ⴚ
    charMap[0x10ba] = codePointToUTF8(0x2d1a); //    # Ⴛ --> ⴛ
    charMap[0x10bb] = codePointToUTF8(0x2d1b); //    # Ⴜ --> ⴜ
    charMap[0x10bc] = codePointToUTF8(0x2d1c); //    # Ⴝ --> ⴝ
    charMap[0x10bd] = codePointToUTF8(0x2d1d); //    # Ⴞ --> ⴞ
    charMap[0x10be] = codePointToUTF8(0x2d1e); //    # Ⴟ --> ⴟ
    charMap[0x10bf] = codePointToUTF8(0x2d1f); //    # Ⴠ --> ⴠ
    charMap[0x10c0] = codePointToUTF8(0x2d20); //    # Ⴡ --> ⴡ
    charMap[0x10c1] = codePointToUTF8(0x2d21); //    # Ⴢ --> ⴢ
    charMap[0x10c2] = codePointToUTF8(0x2d22); //    # Ⴣ --> ⴣ
    charMap[0x10c3] = codePointToUTF8(0x2d23); //    # Ⴤ --> ⴤ
    charMap[0x10c4] = codePointToUTF8(0x2d24); //    # Ⴥ --> ⴥ
    charMap[0x10c5] = codePointToUTF8(0x2d25); //    # Ⴧ --> ⴧ
    charMap[0x10c7] = codePointToUTF8(0x2d27); //    # Ⴭ --> ⴭ
    charMap[0x10cd] = codePointToUTF8(0x2d2d); //    # Ꭰ --> ꭰ
    charMap[0x13a0] = codePointToUTF8(0xab70); //    # Ꭱ --> ꭱ
    charMap[0x13a1] = codePointToUTF8(0xab71); //    # Ꭲ --> ꭲ
    charMap[0x13a2] = codePointToUTF8(0xab72); //    # Ꭳ --> ꭳ
    charMap[0x13a3] = codePointToUTF8(0xab73); //    # Ꭴ --> ꭴ
    charMap[0x13a4] = codePointToUTF8(0xab74); //    # Ꭵ --> ꭵ
    charMap[0x13a5] = codePointToUTF8(0xab75); //    # Ꭶ --> ꭶ
    charMap[0x13a6] = codePointToUTF8(0xab76); //    # Ꭷ --> ꭷ
    charMap[0x13a7] = codePointToUTF8(0xab77); //    # Ꭸ --> ꭸ
    charMap[0x13a8] = codePointToUTF8(0xab78); //    # Ꭹ --> ꭹ
    charMap[0x13a9] = codePointToUTF8(0xab79); //    # Ꭺ --> ꭺ
    charMap[0x13aa] = codePointToUTF8(0xab7a); //    # Ꭻ --> ꭻ
    charMap[0x13ab] = codePointToUTF8(0xab7b); //    # Ꭼ --> ꭼ
    charMap[0x13ac] = codePointToUTF8(0xab7c); //    # Ꭽ --> ꭽ
    charMap[0x13ad] = codePointToUTF8(0xab7d); //    # Ꭾ --> ꭾ
    charMap[0x13ae] = codePointToUTF8(0xab7e); //    # Ꭿ --> ꭿ
    charMap[0x13af] = codePointToUTF8(0xab7f); //    # Ꮀ --> ꮀ
    charMap[0x13b0] = codePointToUTF8(0xab80); //    # Ꮁ --> ꮁ
    charMap[0x13b1] = codePointToUTF8(0xab81); //    # Ꮂ --> ꮂ
    charMap[0x13b2] = codePointToUTF8(0xab82); //    # Ꮃ --> ꮃ
    charMap[0x13b3] = codePointToUTF8(0xab83); //    # Ꮄ --> ꮄ
    charMap[0x13b4] = codePointToUTF8(0xab84); //    # Ꮅ --> ꮅ
    charMap[0x13b5] = codePointToUTF8(0xab85); //    # Ꮆ --> ꮆ
    charMap[0x13b6] = codePointToUTF8(0xab86); //    # Ꮇ --> ꮇ
    charMap[0x13b7] = codePointToUTF8(0xab87); //    # Ꮈ --> ꮈ
    charMap[0x13b8] = codePointToUTF8(0xab88); //    # Ꮉ --> ꮉ
    charMap[0x13b9] = codePointToUTF8(0xab89); //    # Ꮊ --> ꮊ
    charMap[0x13ba] = codePointToUTF8(0xab8a); //    # Ꮋ --> ꮋ
    charMap[0x13bb] = codePointToUTF8(0xab8b); //    # Ꮌ --> ꮌ
    charMap[0x13bc] = codePointToUTF8(0xab8c); //    # Ꮍ --> ꮍ
    charMap[0x13bd] = codePointToUTF8(0xab8d); //    # Ꮎ --> ꮎ
    charMap[0x13be] = codePointToUTF8(0xab8e); //    # Ꮏ --> ꮏ
    charMap[0x13bf] = codePointToUTF8(0xab8f); //    # Ꮐ --> ꮐ
    charMap[0x13c0] = codePointToUTF8(0xab90); //    # Ꮑ --> ꮑ
    charMap[0x13c1] = codePointToUTF8(0xab91); //    # Ꮒ --> ꮒ
    charMap[0x13c2] = codePointToUTF8(0xab92); //    # Ꮓ --> ꮓ
    charMap[0x13c3] = codePointToUTF8(0xab93); //    # Ꮔ --> ꮔ
    charMap[0x13c4] = codePointToUTF8(0xab94); //    # Ꮕ --> ꮕ
    charMap[0x13c5] = codePointToUTF8(0xab95); //    # Ꮖ --> ꮖ
    charMap[0x13c6] = codePointToUTF8(0xab96); //    # Ꮗ --> ꮗ
    charMap[0x13c7] = codePointToUTF8(0xab97); //    # Ꮘ --> ꮘ
    charMap[0x13c8] = codePointToUTF8(0xab98); //    # Ꮙ --> ꮙ
    charMap[0x13c9] = codePointToUTF8(0xab99); //    # Ꮚ --> ꮚ
    charMap[0x13ca] = codePointToUTF8(0xab9a); //    # Ꮛ --> ꮛ
    charMap[0x13cb] = codePointToUTF8(0xab9b); //    # Ꮜ --> ꮜ
    charMap[0x13cc] = codePointToUTF8(0xab9c); //    # Ꮝ --> ꮝ
    charMap[0x13cd] = codePointToUTF8(0xab9d); //    # Ꮞ --> ꮞ
    charMap[0x13ce] = codePointToUTF8(0xab9e); //    # Ꮟ --> ꮟ
    charMap[0x13cf] = codePointToUTF8(0xab9f); //    # Ꮠ --> ꮠ
    charMap[0x13d0] = codePointToUTF8(0xaba0); //    # Ꮡ --> ꮡ
    charMap[0x13d1] = codePointToUTF8(0xaba1); //    # Ꮢ --> ꮢ
    charMap[0x13d2] = codePointToUTF8(0xaba2); //    # Ꮣ --> ꮣ
    charMap[0x13d3] = codePointToUTF8(0xaba3); //    # Ꮤ --> ꮤ
    charMap[0x13d4] = codePointToUTF8(0xaba4); //    # Ꮥ --> ꮥ
    charMap[0x13d5] = codePointToUTF8(0xaba5); //    # Ꮦ --> ꮦ
    charMap[0x13d6] = codePointToUTF8(0xaba6); //    # Ꮧ --> ꮧ
    charMap[0x13d7] = codePointToUTF8(0xaba7); //    # Ꮨ --> ꮨ
    charMap[0x13d8] = codePointToUTF8(0xaba8); //    # Ꮩ --> ꮩ
    charMap[0x13d9] = codePointToUTF8(0xaba9); //    # Ꮪ --> ꮪ
    charMap[0x13da] = codePointToUTF8(0xabaa); //    # Ꮫ --> ꮫ
    charMap[0x13db] = codePointToUTF8(0xabab); //    # Ꮬ --> ꮬ
    charMap[0x13dc] = codePointToUTF8(0xabac); //    # Ꮭ --> ꮭ
    charMap[0x13dd] = codePointToUTF8(0xabad); //    # Ꮮ --> ꮮ
    charMap[0x13de] = codePointToUTF8(0xabae); //    # Ꮯ --> ꮯ
    charMap[0x13df] = codePointToUTF8(0xabaf); //    # Ꮰ --> ꮰ
    charMap[0x13e0] = codePointToUTF8(0xabb0); //    # Ꮱ --> ꮱ
    charMap[0x13e1] = codePointToUTF8(0xabb1); //    # Ꮲ --> ꮲ
    charMap[0x13e2] = codePointToUTF8(0xabb2); //    # Ꮳ --> ꮳ
    charMap[0x13e3] = codePointToUTF8(0xabb3); //    # Ꮴ --> ꮴ
    charMap[0x13e4] = codePointToUTF8(0xabb4); //    # Ꮵ --> ꮵ
    charMap[0x13e5] = codePointToUTF8(0xabb5); //    # Ꮶ --> ꮶ
    charMap[0x13e6] = codePointToUTF8(0xabb6); //    # Ꮷ --> ꮷ
    charMap[0x13e7] = codePointToUTF8(0xabb7); //    # Ꮸ --> ꮸ
    charMap[0x13e8] = codePointToUTF8(0xabb8); //    # Ꮹ --> ꮹ
    charMap[0x13e9] = codePointToUTF8(0xabb9); //    # Ꮺ --> ꮺ
    charMap[0x13ea] = codePointToUTF8(0xabba); //    # Ꮻ --> ꮻ
    charMap[0x13eb] = codePointToUTF8(0xabbb); //    # Ꮼ --> ꮼ
    charMap[0x13ec] = codePointToUTF8(0xabbc); //    # Ꮽ --> ꮽ
    charMap[0x13ed] = codePointToUTF8(0xabbd); //    # Ꮾ --> ꮾ
    charMap[0x13ee] = codePointToUTF8(0xabbe); //    # Ꮿ --> ꮿ
    charMap[0x13ef] = codePointToUTF8(0xabbf); //    # Ᏸ --> ᏸ
    charMap[0x13f0] = codePointToUTF8(0x13f8); //    # Ᏹ --> ᏹ
    charMap[0x13f1] = codePointToUTF8(0x13f9); //    # Ᏺ --> ᏺ
    charMap[0x13f2] = codePointToUTF8(0x13fa); //    # Ᏻ --> ᏻ
    charMap[0x13f3] = codePointToUTF8(0x13fb); //    # Ᏼ --> ᏼ
    charMap[0x13f4] = codePointToUTF8(0x13fc); //    # Ᏽ --> ᏽ
    charMap[0x13f5] = codePointToUTF8(0x13fd); //    # ᬻ --> ᬵ
    charMap[0x1b3b] = codePointToUTF8(0x1b35); //    # ᬽ --> ᬵ
    charMap[0x1b3d] = codePointToUTF8(0x1b35); //    # ᭃ --> ᬵ
    charMap[0x1b43] = codePointToUTF8(0x1b35); //    # Ḁ --> a
    charMap[0x1e00] = codePointToUTF8(0x0061); //    # ḁ --> a
    charMap[0x1e01] = codePointToUTF8(0x0061); //    # Ḃ --> b
    charMap[0x1e02] = codePointToUTF8(0x0062); //    # ḃ --> b
    charMap[0x1e03] = codePointToUTF8(0x0062); //    # Ḅ --> b
    charMap[0x1e04] = codePointToUTF8(0x0062); //    # ḅ --> b
    charMap[0x1e05] = codePointToUTF8(0x0062); //    # Ḇ --> b
    charMap[0x1e06] = codePointToUTF8(0x0062); //    # ḇ --> b
    charMap[0x1e07] = codePointToUTF8(0x0062); //    # Ḉ --> c
    charMap[0x1e08] = codePointToUTF8(0x0063); //    # ḉ --> c
    charMap[0x1e09] = codePointToUTF8(0x0063); //    # Ḋ --> d
    charMap[0x1e0a] = codePointToUTF8(0x0064); //    # ḋ --> d
    charMap[0x1e0b] = codePointToUTF8(0x0064); //    # Ḍ --> d
    charMap[0x1e0c] = codePointToUTF8(0x0064); //    # ḍ --> d
    charMap[0x1e0d] = codePointToUTF8(0x0064); //    # Ḏ --> d
    charMap[0x1e0e] = codePointToUTF8(0x0064); //    # ḏ --> d
    charMap[0x1e0f] = codePointToUTF8(0x0064); //    # Ḑ --> d
    charMap[0x1e10] = codePointToUTF8(0x0064); //    # ḑ --> d
    charMap[0x1e11] = codePointToUTF8(0x0064); //    # Ḓ --> d
    charMap[0x1e12] = codePointToUTF8(0x0064); //    # ḓ --> d
    charMap[0x1e13] = codePointToUTF8(0x0064); //    # Ḕ --> e
    charMap[0x1e14] = codePointToUTF8(0x0065); //    # ḕ --> e
    charMap[0x1e15] = codePointToUTF8(0x0065); //    # Ḗ --> e
    charMap[0x1e16] = codePointToUTF8(0x0065); //    # ḗ --> e
    charMap[0x1e17] = codePointToUTF8(0x0065); //    # Ḙ --> e
    charMap[0x1e18] = codePointToUTF8(0x0065); //    # ḙ --> e
    charMap[0x1e19] = codePointToUTF8(0x0065); //    # Ḛ --> e
    charMap[0x1e1a] = codePointToUTF8(0x0065); //    # ḛ --> e
    charMap[0x1e1b] = codePointToUTF8(0x0065); //    # Ḝ --> e
    charMap[0x1e1c] = codePointToUTF8(0x0065); //    # ḝ --> e
    charMap[0x1e1d] = codePointToUTF8(0x0065); //    # Ḟ --> f
    charMap[0x1e1e] = codePointToUTF8(0x0066); //    # ḟ --> f
    charMap[0x1e1f] = codePointToUTF8(0x0066); //    # Ḡ --> g
    charMap[0x1e20] = codePointToUTF8(0x0067); //    # ḡ --> g
    charMap[0x1e21] = codePointToUTF8(0x0067); //    # Ḣ --> h
    charMap[0x1e22] = codePointToUTF8(0x0068); //    # ḣ --> h
    charMap[0x1e23] = codePointToUTF8(0x0068); //    # Ḥ --> h
    charMap[0x1e24] = codePointToUTF8(0x0068); //    # ḥ --> h
    charMap[0x1e25] = codePointToUTF8(0x0068); //    # Ḧ --> h
    charMap[0x1e26] = codePointToUTF8(0x0068); //    # ḧ --> h
    charMap[0x1e27] = codePointToUTF8(0x0068); //    # Ḩ --> h
    charMap[0x1e28] = codePointToUTF8(0x0068); //    # ḩ --> h
    charMap[0x1e29] = codePointToUTF8(0x0068); //    # Ḫ --> h
    charMap[0x1e2a] = codePointToUTF8(0x0068); //    # ḫ --> h
    charMap[0x1e2b] = codePointToUTF8(0x0068); //    # Ḭ --> i
    charMap[0x1e2c] = codePointToUTF8(0x0069); //    # ḭ --> i
    charMap[0x1e2d] = codePointToUTF8(0x0069); //    # Ḯ --> i
    charMap[0x1e2e] = codePointToUTF8(0x0069); //    # ḯ --> i
    charMap[0x1e2f] = codePointToUTF8(0x0069); //    # Ḱ --> k
    charMap[0x1e30] = codePointToUTF8(0x006b); //    # ḱ --> k
    charMap[0x1e31] = codePointToUTF8(0x006b); //    # Ḳ --> k
    charMap[0x1e32] = codePointToUTF8(0x006b); //    # ḳ --> k
    charMap[0x1e33] = codePointToUTF8(0x006b); //    # Ḵ --> k
    charMap[0x1e34] = codePointToUTF8(0x006b); //    # ḵ --> k
    charMap[0x1e35] = codePointToUTF8(0x006b); //    # Ḷ --> l
    charMap[0x1e36] = codePointToUTF8(0x006c); //    # ḷ --> l
    charMap[0x1e37] = codePointToUTF8(0x006c); //    # Ḹ --> l
    charMap[0x1e38] = codePointToUTF8(0x006c); //    # ḹ --> l
    charMap[0x1e39] = codePointToUTF8(0x006c); //    # Ḻ --> l
    charMap[0x1e3a] = codePointToUTF8(0x006c); //    # ḻ --> l
    charMap[0x1e3b] = codePointToUTF8(0x006c); //    # Ḽ --> l
    charMap[0x1e3c] = codePointToUTF8(0x006c); //    # ḽ --> l
    charMap[0x1e3d] = codePointToUTF8(0x006c); //    # Ḿ --> m
    charMap[0x1e3e] = codePointToUTF8(0x006d); //    # ḿ --> m
    charMap[0x1e3f] = codePointToUTF8(0x006d); //    # Ṁ --> m
    charMap[0x1e40] = codePointToUTF8(0x006d); //    # ṁ --> m
    charMap[0x1e41] = codePointToUTF8(0x006d); //    # Ṃ --> m
    charMap[0x1e42] = codePointToUTF8(0x006d); //    # ṃ --> m
    charMap[0x1e43] = codePointToUTF8(0x006d); //    # Ṅ --> n
    charMap[0x1e44] = codePointToUTF8(0x006e); //    # ṅ --> n
    charMap[0x1e45] = codePointToUTF8(0x006e); //    # Ṇ --> n
    charMap[0x1e46] = codePointToUTF8(0x006e); //    # ṇ --> n
    charMap[0x1e47] = codePointToUTF8(0x006e); //    # Ṉ --> n
    charMap[0x1e48] = codePointToUTF8(0x006e); //    # ṉ --> n
    charMap[0x1e49] = codePointToUTF8(0x006e); //    # Ṋ --> n
    charMap[0x1e4a] = codePointToUTF8(0x006e); //    # ṋ --> n
    charMap[0x1e4b] = codePointToUTF8(0x006e); //    # Ṍ --> o
    charMap[0x1e4c] = codePointToUTF8(0x006f); //    # ṍ --> o
    charMap[0x1e4d] = codePointToUTF8(0x006f); //    # Ṏ --> o
    charMap[0x1e4e] = codePointToUTF8(0x006f); //    # ṏ --> o
    charMap[0x1e4f] = codePointToUTF8(0x006f); //    # Ṑ --> o
    charMap[0x1e50] = codePointToUTF8(0x006f); //    # ṑ --> o
    charMap[0x1e51] = codePointToUTF8(0x006f); //    # Ṓ --> o
    charMap[0x1e52] = codePointToUTF8(0x006f); //    # ṓ --> o
    charMap[0x1e53] = codePointToUTF8(0x006f); //    # Ṕ --> p
    charMap[0x1e54] = codePointToUTF8(0x0070); //    # ṕ --> p
    charMap[0x1e55] = codePointToUTF8(0x0070); //    # Ṗ --> p
    charMap[0x1e56] = codePointToUTF8(0x0070); //    # ṗ --> p
    charMap[0x1e57] = codePointToUTF8(0x0070); //    # Ṙ --> r
    charMap[0x1e58] = codePointToUTF8(0x0072); //    # ṙ --> r
    charMap[0x1e59] = codePointToUTF8(0x0072); //    # Ṛ --> r
    charMap[0x1e5a] = codePointToUTF8(0x0072); //    # ṛ --> r
    charMap[0x1e5b] = codePointToUTF8(0x0072); //    # Ṝ --> r
    charMap[0x1e5c] = codePointToUTF8(0x0072); //    # ṝ --> r
    charMap[0x1e5d] = codePointToUTF8(0x0072); //    # Ṟ --> r
    charMap[0x1e5e] = codePointToUTF8(0x0072); //    # ṟ --> r
    charMap[0x1e5f] = codePointToUTF8(0x0072); //    # Ṡ --> s
    charMap[0x1e60] = codePointToUTF8(0x0073); //    # ṡ --> s
    charMap[0x1e61] = codePointToUTF8(0x0073); //    # Ṣ --> s
    charMap[0x1e62] = codePointToUTF8(0x0073); //    # ṣ --> s
    charMap[0x1e63] = codePointToUTF8(0x0073); //    # Ṥ --> s
    charMap[0x1e64] = codePointToUTF8(0x0073); //    # ṥ --> s
    charMap[0x1e65] = codePointToUTF8(0x0073); //    # Ṧ --> s
    charMap[0x1e66] = codePointToUTF8(0x0073); //    # ṧ --> s
    charMap[0x1e67] = codePointToUTF8(0x0073); //    # Ṩ --> s
    charMap[0x1e68] = codePointToUTF8(0x0073); //    # ṩ --> s
    charMap[0x1e69] = codePointToUTF8(0x0073); //    # Ṫ --> t
    charMap[0x1e6a] = codePointToUTF8(0x0074); //    # ṫ --> t
    charMap[0x1e6b] = codePointToUTF8(0x0074); //    # Ṭ --> t
    charMap[0x1e6c] = codePointToUTF8(0x0074); //    # ṭ --> t
    charMap[0x1e6d] = codePointToUTF8(0x0074); //    # Ṯ --> t
    charMap[0x1e6e] = codePointToUTF8(0x0074); //    # ṯ --> t
    charMap[0x1e6f] = codePointToUTF8(0x0074); //    # Ṱ --> t
    charMap[0x1e70] = codePointToUTF8(0x0074); //    # ṱ --> t
    charMap[0x1e71] = codePointToUTF8(0x0074); //    # Ṳ --> u
    charMap[0x1e72] = codePointToUTF8(0x0075); //    # ṳ --> u
    charMap[0x1e73] = codePointToUTF8(0x0075); //    # Ṵ --> u
    charMap[0x1e74] = codePointToUTF8(0x0075); //    # ṵ --> u
    charMap[0x1e75] = codePointToUTF8(0x0075); //    # Ṷ --> u
    charMap[0x1e76] = codePointToUTF8(0x0075); //    # ṷ --> u
    charMap[0x1e77] = codePointToUTF8(0x0075); //    # Ṹ --> u
    charMap[0x1e78] = codePointToUTF8(0x0075); //    # ṹ --> u
    charMap[0x1e79] = codePointToUTF8(0x0075); //    # Ṻ --> u
    charMap[0x1e7a] = codePointToUTF8(0x0075); //    # ṻ --> u
    charMap[0x1e7b] = codePointToUTF8(0x0075); //    # Ṽ --> v
    charMap[0x1e7c] = codePointToUTF8(0x0076); //    # ṽ --> v
    charMap[0x1e7d] = codePointToUTF8(0x0076); //    # Ṿ --> v
    charMap[0x1e7e] = codePointToUTF8(0x0076); //    # ṿ --> v
    charMap[0x1e7f] = codePointToUTF8(0x0076); //    # Ẁ --> w
    charMap[0x1e80] = codePointToUTF8(0x0077); //    # ẁ --> w
    charMap[0x1e81] = codePointToUTF8(0x0077); //    # Ẃ --> w
    charMap[0x1e82] = codePointToUTF8(0x0077); //    # ẃ --> w
    charMap[0x1e83] = codePointToUTF8(0x0077); //    # Ẅ --> w
    charMap[0x1e84] = codePointToUTF8(0x0077); //    # ẅ --> w
    charMap[0x1e85] = codePointToUTF8(0x0077); //    # Ẇ --> w
    charMap[0x1e86] = codePointToUTF8(0x0077); //    # ẇ --> w
    charMap[0x1e87] = codePointToUTF8(0x0077); //    # Ẉ --> w
    charMap[0x1e88] = codePointToUTF8(0x0077); //    # ẉ --> w
    charMap[0x1e89] = codePointToUTF8(0x0077); //    # Ẋ --> x
    charMap[0x1e8a] = codePointToUTF8(0x0078); //    # ẋ --> x
    charMap[0x1e8b] = codePointToUTF8(0x0078); //    # Ẍ --> x
    charMap[0x1e8c] = codePointToUTF8(0x0078); //    # ẍ --> x
    charMap[0x1e8d] = codePointToUTF8(0x0078); //    # Ẏ --> y
    charMap[0x1e8e] = codePointToUTF8(0x0079); //    # ẏ --> y
    charMap[0x1e8f] = codePointToUTF8(0x0079); //    # Ẑ --> z
    charMap[0x1e90] = codePointToUTF8(0x007a); //    # ẑ --> z
    charMap[0x1e91] = codePointToUTF8(0x007a); //    # Ẓ --> z
    charMap[0x1e92] = codePointToUTF8(0x007a); //    # ẓ --> z
    charMap[0x1e93] = codePointToUTF8(0x007a); //    # Ẕ --> z
    charMap[0x1e94] = codePointToUTF8(0x007a); //    # ẕ --> z
    charMap[0x1e95] = codePointToUTF8(0x007a); //    # ẖ --> h
    charMap[0x1e96] = codePointToUTF8(0x0068); //    # ẗ --> t
    charMap[0x1e97] = codePointToUTF8(0x0074); //    # ẘ --> w
    charMap[0x1e98] = codePointToUTF8(0x0077); //    # ẙ --> y
    charMap[0x1e99] = codePointToUTF8(0x0079); //    # ẛ --> ſ
    charMap[0x1e9b] = codePointToUTF8(0x017f); //    # ẞ --> ß
    charMap[0x1e9e] = codePointToUTF8(0x00df); //    # Ạ --> a
    charMap[0x1ea0] = codePointToUTF8(0x0061); //    # ạ --> a
    charMap[0x1ea1] = codePointToUTF8(0x0061); //    # Ả --> a
    charMap[0x1ea2] = codePointToUTF8(0x0061); //    # ả --> a
    charMap[0x1ea3] = codePointToUTF8(0x0061); //    # Ấ --> a
    charMap[0x1ea4] = codePointToUTF8(0x0061); //    # ấ --> a
    charMap[0x1ea5] = codePointToUTF8(0x0061); //    # Ầ --> a
    charMap[0x1ea6] = codePointToUTF8(0x0061); //    # ầ --> a
    charMap[0x1ea7] = codePointToUTF8(0x0061); //    # Ẩ --> a
    charMap[0x1ea8] = codePointToUTF8(0x0061); //    # ẩ --> a
    charMap[0x1ea9] = codePointToUTF8(0x0061); //    # Ẫ --> a
    charMap[0x1eaa] = codePointToUTF8(0x0061); //    # ẫ --> a
    charMap[0x1eab] = codePointToUTF8(0x0061); //    # Ậ --> a
    charMap[0x1eac] = codePointToUTF8(0x0061); //    # ậ --> a
    charMap[0x1ead] = codePointToUTF8(0x0061); //    # Ắ --> a
    charMap[0x1eae] = codePointToUTF8(0x0061); //    # ắ --> a
    charMap[0x1eaf] = codePointToUTF8(0x0061); //    # Ằ --> a
    charMap[0x1eb0] = codePointToUTF8(0x0061); //    # ằ --> a
    charMap[0x1eb1] = codePointToUTF8(0x0061); //    # Ẳ --> a
    charMap[0x1eb2] = codePointToUTF8(0x0061); //    # ẳ --> a
    charMap[0x1eb3] = codePointToUTF8(0x0061); //    # Ẵ --> a
    charMap[0x1eb4] = codePointToUTF8(0x0061); //    # ẵ --> a
    charMap[0x1eb5] = codePointToUTF8(0x0061); //    # Ặ --> a
    charMap[0x1eb6] = codePointToUTF8(0x0061); //    # ặ --> a
    charMap[0x1eb7] = codePointToUTF8(0x0061); //    # Ẹ --> e
    charMap[0x1eb8] = codePointToUTF8(0x0065); //    # ẹ --> e
    charMap[0x1eb9] = codePointToUTF8(0x0065); //    # Ẻ --> e
    charMap[0x1eba] = codePointToUTF8(0x0065); //    # ẻ --> e
    charMap[0x1ebb] = codePointToUTF8(0x0065); //    # Ẽ --> e
    charMap[0x1ebc] = codePointToUTF8(0x0065); //    # ẽ --> e
    charMap[0x1ebd] = codePointToUTF8(0x0065); //    # Ế --> e
    charMap[0x1ebe] = codePointToUTF8(0x0065); //    # ế --> e
    charMap[0x1ebf] = codePointToUTF8(0x0065); //    # Ề --> e
    charMap[0x1ec0] = codePointToUTF8(0x0065); //    # ề --> e
    charMap[0x1ec1] = codePointToUTF8(0x0065); //    # Ể --> e
    charMap[0x1ec2] = codePointToUTF8(0x0065); //    # ể --> e
    charMap[0x1ec3] = codePointToUTF8(0x0065); //    # Ễ --> e
    charMap[0x1ec4] = codePointToUTF8(0x0065); //    # ễ --> e
    charMap[0x1ec5] = codePointToUTF8(0x0065); //    # Ệ --> e
    charMap[0x1ec6] = codePointToUTF8(0x0065); //    # ệ --> e
    charMap[0x1ec7] = codePointToUTF8(0x0065); //    # Ỉ --> i
    charMap[0x1ec8] = codePointToUTF8(0x0069); //    # ỉ --> i
    charMap[0x1ec9] = codePointToUTF8(0x0069); //    # Ị --> i
    charMap[0x1eca] = codePointToUTF8(0x0069); //    # ị --> i
    charMap[0x1ecb] = codePointToUTF8(0x0069); //    # Ọ --> o
    charMap[0x1ecc] = codePointToUTF8(0x006f); //    # ọ --> o
    charMap[0x1ecd] = codePointToUTF8(0x006f); //    # Ỏ --> o
    charMap[0x1ece] = codePointToUTF8(0x006f); //    # ỏ --> o
    charMap[0x1ecf] = codePointToUTF8(0x006f); //    # Ố --> o
    charMap[0x1ed0] = codePointToUTF8(0x006f); //    # ố --> o
    charMap[0x1ed1] = codePointToUTF8(0x006f); //    # Ồ --> o
    charMap[0x1ed2] = codePointToUTF8(0x006f); //    # ồ --> o
    charMap[0x1ed3] = codePointToUTF8(0x006f); //    # Ổ --> o
    charMap[0x1ed4] = codePointToUTF8(0x006f); //    # ổ --> o
    charMap[0x1ed5] = codePointToUTF8(0x006f); //    # Ỗ --> o
    charMap[0x1ed6] = codePointToUTF8(0x006f); //    # ỗ --> o
    charMap[0x1ed7] = codePointToUTF8(0x006f); //    # Ộ --> o
    charMap[0x1ed8] = codePointToUTF8(0x006f); //    # ộ --> o
    charMap[0x1ed9] = codePointToUTF8(0x006f); //    # Ớ --> o
    charMap[0x1eda] = codePointToUTF8(0x006f); //    # ớ --> o
    charMap[0x1edb] = codePointToUTF8(0x006f); //    # Ờ --> o
    charMap[0x1edc] = codePointToUTF8(0x006f); //    # ờ --> o
    charMap[0x1edd] = codePointToUTF8(0x006f); //    # Ở --> o
    charMap[0x1ede] = codePointToUTF8(0x006f); //    # ở --> o
    charMap[0x1edf] = codePointToUTF8(0x006f); //    # Ỡ --> o
    charMap[0x1ee0] = codePointToUTF8(0x006f); //    # ỡ --> o
    charMap[0x1ee1] = codePointToUTF8(0x006f); //    # Ợ --> o
    charMap[0x1ee2] = codePointToUTF8(0x006f); //    # ợ --> o
    charMap[0x1ee3] = codePointToUTF8(0x006f); //    # Ụ --> u
    charMap[0x1ee4] = codePointToUTF8(0x0075); //    # ụ --> u
    charMap[0x1ee5] = codePointToUTF8(0x0075); //    # Ủ --> u
    charMap[0x1ee6] = codePointToUTF8(0x0075); //    # ủ --> u
    charMap[0x1ee7] = codePointToUTF8(0x0075); //    # Ứ --> u
    charMap[0x1ee8] = codePointToUTF8(0x0075); //    # ứ --> u
    charMap[0x1ee9] = codePointToUTF8(0x0075); //    # Ừ --> u
    charMap[0x1eea] = codePointToUTF8(0x0075); //    # ừ --> u
    charMap[0x1eeb] = codePointToUTF8(0x0075); //    # Ử --> u
    charMap[0x1eec] = codePointToUTF8(0x0075); //    # ử --> u
    charMap[0x1eed] = codePointToUTF8(0x0075); //    # Ữ --> u
    charMap[0x1eee] = codePointToUTF8(0x0075); //    # ữ --> u
    charMap[0x1eef] = codePointToUTF8(0x0075); //    # Ự --> u
    charMap[0x1ef0] = codePointToUTF8(0x0075); //    # ự --> u
    charMap[0x1ef1] = codePointToUTF8(0x0075); //    # Ỳ --> y
    charMap[0x1ef2] = codePointToUTF8(0x0079); //    # ỳ --> y
    charMap[0x1ef3] = codePointToUTF8(0x0079); //    # Ỵ --> y
    charMap[0x1ef4] = codePointToUTF8(0x0079); //    # ỵ --> y
    charMap[0x1ef5] = codePointToUTF8(0x0079); //    # Ỷ --> y
    charMap[0x1ef6] = codePointToUTF8(0x0079); //    # ỷ --> y
    charMap[0x1ef7] = codePointToUTF8(0x0079); //    # Ỹ --> y
    charMap[0x1ef8] = codePointToUTF8(0x0079); //    # ỹ --> y
    charMap[0x1ef9] = codePointToUTF8(0x0079); //    # Ỻ --> ỻ
    charMap[0x1efa] = codePointToUTF8(0x1efb); //    # Ỽ --> ỽ
    charMap[0x1efc] = codePointToUTF8(0x1efd); //    # Ỿ --> ỿ
    charMap[0x1efe] = codePointToUTF8(0x1eff); //    # ἀ --> α
    charMap[0x1f00] = codePointToUTF8(0x03b1); //    # ἁ --> α
    charMap[0x1f01] = codePointToUTF8(0x03b1); //    # ἂ --> α
    charMap[0x1f02] = codePointToUTF8(0x03b1); //    # ἃ --> α
    charMap[0x1f03] = codePointToUTF8(0x03b1); //    # ἄ --> α
    charMap[0x1f04] = codePointToUTF8(0x03b1); //    # ἅ --> α
    charMap[0x1f05] = codePointToUTF8(0x03b1); //    # ἆ --> α
    charMap[0x1f06] = codePointToUTF8(0x03b1); //    # ἇ --> α
    charMap[0x1f07] = codePointToUTF8(0x03b1); //    # Ἀ --> α
    charMap[0x1f08] = codePointToUTF8(0x03b1); //    # Ἁ --> α
    charMap[0x1f09] = codePointToUTF8(0x03b1); //    # Ἂ --> α
    charMap[0x1f0a] = codePointToUTF8(0x03b1); //    # Ἃ --> α
    charMap[0x1f0b] = codePointToUTF8(0x03b1); //    # Ἄ --> α
    charMap[0x1f0c] = codePointToUTF8(0x03b1); //    # Ἅ --> α
    charMap[0x1f0d] = codePointToUTF8(0x03b1); //    # Ἆ --> α
    charMap[0x1f0e] = codePointToUTF8(0x03b1); //    # Ἇ --> α
    charMap[0x1f0f] = codePointToUTF8(0x03b1); //    # ἐ --> ε
    charMap[0x1f10] = codePointToUTF8(0x03b5); //    # ἑ --> ε
    charMap[0x1f11] = codePointToUTF8(0x03b5); //    # ἒ --> ε
    charMap[0x1f12] = codePointToUTF8(0x03b5); //    # ἓ --> ε
    charMap[0x1f13] = codePointToUTF8(0x03b5); //    # ἔ --> ε
    charMap[0x1f14] = codePointToUTF8(0x03b5); //    # ἕ --> ε
    charMap[0x1f15] = codePointToUTF8(0x03b5); //    # Ἐ --> ε
    charMap[0x1f18] = codePointToUTF8(0x03b5); //    # Ἑ --> ε
    charMap[0x1f19] = codePointToUTF8(0x03b5); //    # Ἒ --> ε
    charMap[0x1f1a] = codePointToUTF8(0x03b5); //    # Ἓ --> ε
    charMap[0x1f1b] = codePointToUTF8(0x03b5); //    # Ἔ --> ε
    charMap[0x1f1c] = codePointToUTF8(0x03b5); //    # Ἕ --> ε
    charMap[0x1f1d] = codePointToUTF8(0x03b5); //    # ἠ --> η
    charMap[0x1f20] = codePointToUTF8(0x03b7); //    # ἡ --> η
    charMap[0x1f21] = codePointToUTF8(0x03b7); //    # ἢ --> η
    charMap[0x1f22] = codePointToUTF8(0x03b7); //    # ἣ --> η
    charMap[0x1f23] = codePointToUTF8(0x03b7); //    # ἤ --> η
    charMap[0x1f24] = codePointToUTF8(0x03b7); //    # ἥ --> η
    charMap[0x1f25] = codePointToUTF8(0x03b7); //    # ἦ --> η
    charMap[0x1f26] = codePointToUTF8(0x03b7); //    # ἧ --> η
    charMap[0x1f27] = codePointToUTF8(0x03b7); //    # Ἠ --> η
    charMap[0x1f28] = codePointToUTF8(0x03b7); //    # Ἡ --> η
    charMap[0x1f29] = codePointToUTF8(0x03b7); //    # Ἢ --> η
    charMap[0x1f2a] = codePointToUTF8(0x03b7); //    # Ἣ --> η
    charMap[0x1f2b] = codePointToUTF8(0x03b7); //    # Ἤ --> η
    charMap[0x1f2c] = codePointToUTF8(0x03b7); //    # Ἥ --> η
    charMap[0x1f2d] = codePointToUTF8(0x03b7); //    # Ἦ --> η
    charMap[0x1f2e] = codePointToUTF8(0x03b7); //    # Ἧ --> η
    charMap[0x1f2f] = codePointToUTF8(0x03b7); //    # ἰ --> ι
    charMap[0x1f30] = codePointToUTF8(0x03b9); //    # ἱ --> ι
    charMap[0x1f31] = codePointToUTF8(0x03b9); //    # ἲ --> ι
    charMap[0x1f32] = codePointToUTF8(0x03b9); //    # ἳ --> ι
    charMap[0x1f33] = codePointToUTF8(0x03b9); //    # ἴ --> ι
    charMap[0x1f34] = codePointToUTF8(0x03b9); //    # ἵ --> ι
    charMap[0x1f35] = codePointToUTF8(0x03b9); //    # ἶ --> ι
    charMap[0x1f36] = codePointToUTF8(0x03b9); //    # ἷ --> ι
    charMap[0x1f37] = codePointToUTF8(0x03b9); //    # Ἰ --> ι
    charMap[0x1f38] = codePointToUTF8(0x03b9); //    # Ἱ --> ι
    charMap[0x1f39] = codePointToUTF8(0x03b9); //    # Ἲ --> ι
    charMap[0x1f3a] = codePointToUTF8(0x03b9); //    # Ἳ --> ι
    charMap[0x1f3b] = codePointToUTF8(0x03b9); //    # Ἴ --> ι
    charMap[0x1f3c] = codePointToUTF8(0x03b9); //    # Ἵ --> ι
    charMap[0x1f3d] = codePointToUTF8(0x03b9); //    # Ἶ --> ι
    charMap[0x1f3e] = codePointToUTF8(0x03b9); //    # Ἷ --> ι
    charMap[0x1f3f] = codePointToUTF8(0x03b9); //    # ὀ --> ο
    charMap[0x1f40] = codePointToUTF8(0x03bf); //    # ὁ --> ο
    charMap[0x1f41] = codePointToUTF8(0x03bf); //    # ὂ --> ο
    charMap[0x1f42] = codePointToUTF8(0x03bf); //    # ὃ --> ο
    charMap[0x1f43] = codePointToUTF8(0x03bf); //    # ὄ --> ο
    charMap[0x1f44] = codePointToUTF8(0x03bf); //    # ὅ --> ο
    charMap[0x1f45] = codePointToUTF8(0x03bf); //    # Ὀ --> ο
    charMap[0x1f48] = codePointToUTF8(0x03bf); //    # Ὁ --> ο
    charMap[0x1f49] = codePointToUTF8(0x03bf); //    # Ὂ --> ο
    charMap[0x1f4a] = codePointToUTF8(0x03bf); //    # Ὃ --> ο
    charMap[0x1f4b] = codePointToUTF8(0x03bf); //    # Ὄ --> ο
    charMap[0x1f4c] = codePointToUTF8(0x03bf); //    # Ὅ --> ο
    charMap[0x1f4d] = codePointToUTF8(0x03bf); //    # ὐ --> υ
    charMap[0x1f50] = codePointToUTF8(0x03c5); //    # ὑ --> υ
    charMap[0x1f51] = codePointToUTF8(0x03c5); //    # ὒ --> υ
    charMap[0x1f52] = codePointToUTF8(0x03c5); //    # ὓ --> υ
    charMap[0x1f53] = codePointToUTF8(0x03c5); //    # ὔ --> υ
    charMap[0x1f54] = codePointToUTF8(0x03c5); //    # ὕ --> υ
    charMap[0x1f55] = codePointToUTF8(0x03c5); //    # ὖ --> υ
    charMap[0x1f56] = codePointToUTF8(0x03c5); //    # ὗ --> υ
    charMap[0x1f57] = codePointToUTF8(0x03c5); //    # Ὑ --> υ
    charMap[0x1f59] = codePointToUTF8(0x03c5); //    # Ὓ --> υ
    charMap[0x1f5b] = codePointToUTF8(0x03c5); //    # Ὕ --> υ
    charMap[0x1f5d] = codePointToUTF8(0x03c5); //    # Ὗ --> υ
    charMap[0x1f5f] = codePointToUTF8(0x03c5); //    # ὠ --> ω
    charMap[0x1f60] = codePointToUTF8(0x03c9); //    # ὡ --> ω
    charMap[0x1f61] = codePointToUTF8(0x03c9); //    # ὢ --> ω
    charMap[0x1f62] = codePointToUTF8(0x03c9); //    # ὣ --> ω
    charMap[0x1f63] = codePointToUTF8(0x03c9); //    # ὤ --> ω
    charMap[0x1f64] = codePointToUTF8(0x03c9); //    # ὥ --> ω
    charMap[0x1f65] = codePointToUTF8(0x03c9); //    # ὦ --> ω
    charMap[0x1f66] = codePointToUTF8(0x03c9); //    # ὧ --> ω
    charMap[0x1f67] = codePointToUTF8(0x03c9); //    # Ὠ --> ω
    charMap[0x1f68] = codePointToUTF8(0x03c9); //    # Ὡ --> ω
    charMap[0x1f69] = codePointToUTF8(0x03c9); //    # Ὢ --> ω
    charMap[0x1f6a] = codePointToUTF8(0x03c9); //    # Ὣ --> ω
    charMap[0x1f6b] = codePointToUTF8(0x03c9); //    # Ὤ --> ω
    charMap[0x1f6c] = codePointToUTF8(0x03c9); //    # Ὥ --> ω
    charMap[0x1f6d] = codePointToUTF8(0x03c9); //    # Ὦ --> ω
    charMap[0x1f6e] = codePointToUTF8(0x03c9); //    # Ὧ --> ω
    charMap[0x1f6f] = codePointToUTF8(0x03c9); //    # ὰ --> α
    charMap[0x1f70] = codePointToUTF8(0x03b1); //    # ά --> α
    charMap[0x1f71] = codePointToUTF8(0x03b1); //    # ὲ --> ε
    charMap[0x1f72] = codePointToUTF8(0x03b5); //    # έ --> ε
    charMap[0x1f73] = codePointToUTF8(0x03b5); //    # ὴ --> η
    charMap[0x1f74] = codePointToUTF8(0x03b7); //    # ή --> η
    charMap[0x1f75] = codePointToUTF8(0x03b7); //    # ὶ --> ι
    charMap[0x1f76] = codePointToUTF8(0x03b9); //    # ί --> ι
    charMap[0x1f77] = codePointToUTF8(0x03b9); //    # ὸ --> ο
    charMap[0x1f78] = codePointToUTF8(0x03bf); //    # ό --> ο
    charMap[0x1f79] = codePointToUTF8(0x03bf); //    # ὺ --> υ
    charMap[0x1f7a] = codePointToUTF8(0x03c5); //    # ύ --> υ
    charMap[0x1f7b] = codePointToUTF8(0x03c5); //    # ὼ --> ω
    charMap[0x1f7c] = codePointToUTF8(0x03c9); //    # ώ --> ω
    charMap[0x1f7d] = codePointToUTF8(0x03c9); //    # ᾀ --> α
    charMap[0x1f80] = codePointToUTF8(0x03b1); //    # ᾁ --> α
    charMap[0x1f81] = codePointToUTF8(0x03b1); //    # ᾂ --> α
    charMap[0x1f82] = codePointToUTF8(0x03b1); //    # ᾃ --> α
    charMap[0x1f83] = codePointToUTF8(0x03b1); //    # ᾄ --> α
    charMap[0x1f84] = codePointToUTF8(0x03b1); //    # ᾅ --> α
    charMap[0x1f85] = codePointToUTF8(0x03b1); //    # ᾆ --> α
    charMap[0x1f86] = codePointToUTF8(0x03b1); //    # ᾇ --> α
    charMap[0x1f87] = codePointToUTF8(0x03b1); //    # ᾈ --> α
    charMap[0x1f88] = codePointToUTF8(0x03b1); //    # ᾉ --> α
    charMap[0x1f89] = codePointToUTF8(0x03b1); //    # ᾊ --> α
    charMap[0x1f8a] = codePointToUTF8(0x03b1); //    # ᾋ --> α
    charMap[0x1f8b] = codePointToUTF8(0x03b1); //    # ᾌ --> α
    charMap[0x1f8c] = codePointToUTF8(0x03b1); //    # ᾍ --> α
    charMap[0x1f8d] = codePointToUTF8(0x03b1); //    # ᾎ --> α
    charMap[0x1f8e] = codePointToUTF8(0x03b1); //    # ᾏ --> α
    charMap[0x1f8f] = codePointToUTF8(0x03b1); //    # ᾐ --> η
    charMap[0x1f90] = codePointToUTF8(0x03b7); //    # ᾑ --> η
    charMap[0x1f91] = codePointToUTF8(0x03b7); //    # ᾒ --> η
    charMap[0x1f92] = codePointToUTF8(0x03b7); //    # ᾓ --> η
    charMap[0x1f93] = codePointToUTF8(0x03b7); //    # ᾔ --> η
    charMap[0x1f94] = codePointToUTF8(0x03b7); //    # ᾕ --> η
    charMap[0x1f95] = codePointToUTF8(0x03b7); //    # ᾖ --> η
    charMap[0x1f96] = codePointToUTF8(0x03b7); //    # ᾗ --> η
    charMap[0x1f97] = codePointToUTF8(0x03b7); //    # ᾘ --> η
    charMap[0x1f98] = codePointToUTF8(0x03b7); //    # ᾙ --> η
    charMap[0x1f99] = codePointToUTF8(0x03b7); //    # ᾚ --> η
    charMap[0x1f9a] = codePointToUTF8(0x03b7); //    # ᾛ --> η
    charMap[0x1f9b] = codePointToUTF8(0x03b7); //    # ᾜ --> η
    charMap[0x1f9c] = codePointToUTF8(0x03b7); //    # ᾝ --> η
    charMap[0x1f9d] = codePointToUTF8(0x03b7); //    # ᾞ --> η
    charMap[0x1f9e] = codePointToUTF8(0x03b7); //    # ᾟ --> η
    charMap[0x1f9f] = codePointToUTF8(0x03b7); //    # ᾠ --> ω
    charMap[0x1fa0] = codePointToUTF8(0x03c9); //    # ᾡ --> ω
    charMap[0x1fa1] = codePointToUTF8(0x03c9); //    # ᾢ --> ω
    charMap[0x1fa2] = codePointToUTF8(0x03c9); //    # ᾣ --> ω
    charMap[0x1fa3] = codePointToUTF8(0x03c9); //    # ᾤ --> ω
    charMap[0x1fa4] = codePointToUTF8(0x03c9); //    # ᾥ --> ω
    charMap[0x1fa5] = codePointToUTF8(0x03c9); //    # ᾦ --> ω
    charMap[0x1fa6] = codePointToUTF8(0x03c9); //    # ᾧ --> ω
    charMap[0x1fa7] = codePointToUTF8(0x03c9); //    # ᾨ --> ω
    charMap[0x1fa8] = codePointToUTF8(0x03c9); //    # ᾩ --> ω
    charMap[0x1fa9] = codePointToUTF8(0x03c9); //    # ᾪ --> ω
    charMap[0x1faa] = codePointToUTF8(0x03c9); //    # ᾫ --> ω
    charMap[0x1fab] = codePointToUTF8(0x03c9); //    # ᾬ --> ω
    charMap[0x1fac] = codePointToUTF8(0x03c9); //    # ᾭ --> ω
    charMap[0x1fad] = codePointToUTF8(0x03c9); //    # ᾮ --> ω
    charMap[0x1fae] = codePointToUTF8(0x03c9); //    # ᾯ --> ω
    charMap[0x1faf] = codePointToUTF8(0x03c9); //    # ᾰ --> α
    charMap[0x1fb0] = codePointToUTF8(0x03b1); //    # ᾱ --> α
    charMap[0x1fb1] = codePointToUTF8(0x03b1); //    # ᾲ --> α
    charMap[0x1fb2] = codePointToUTF8(0x03b1); //    # ᾳ --> α
    charMap[0x1fb3] = codePointToUTF8(0x03b1); //    # ᾴ --> α
    charMap[0x1fb4] = codePointToUTF8(0x03b1); //    # ᾶ --> α
    charMap[0x1fb6] = codePointToUTF8(0x03b1); //    # ᾷ --> α
    charMap[0x1fb7] = codePointToUTF8(0x03b1); //    # Ᾰ --> α
    charMap[0x1fb8] = codePointToUTF8(0x03b1); //    # Ᾱ --> α
    charMap[0x1fb9] = codePointToUTF8(0x03b1); //    # Ὰ --> α
    charMap[0x1fba] = codePointToUTF8(0x03b1); //    # Ά --> α
    charMap[0x1fbb] = codePointToUTF8(0x03b1); //    # ᾼ --> α
    charMap[0x1fbc] = codePointToUTF8(0x03b1); //    # ῁ --> ¨
    charMap[0x1fc1] = codePointToUTF8(0x00a8); //    # ῂ --> η
    charMap[0x1fc2] = codePointToUTF8(0x03b7); //    # ῃ --> η
    charMap[0x1fc3] = codePointToUTF8(0x03b7); //    # ῄ --> η
    charMap[0x1fc4] = codePointToUTF8(0x03b7); //    # ῆ --> η
    charMap[0x1fc6] = codePointToUTF8(0x03b7); //    # ῇ --> η
    charMap[0x1fc7] = codePointToUTF8(0x03b7); //    # Ὲ --> ε
    charMap[0x1fc8] = codePointToUTF8(0x03b5); //    # Έ --> ε
    charMap[0x1fc9] = codePointToUTF8(0x03b5); //    # Ὴ --> η
    charMap[0x1fca] = codePointToUTF8(0x03b7); //    # Ή --> η
    charMap[0x1fcb] = codePointToUTF8(0x03b7); //    # ῌ --> η
    charMap[0x1fcc] = codePointToUTF8(0x03b7); //    # ῍ --> ᾿
    charMap[0x1fcd] = codePointToUTF8(0x1fbf); //    # ῎ --> ᾿
    charMap[0x1fce] = codePointToUTF8(0x1fbf); //    # ῏ --> ᾿
    charMap[0x1fcf] = codePointToUTF8(0x1fbf); //    # ῐ --> ι
    charMap[0x1fd0] = codePointToUTF8(0x03b9); //    # ῑ --> ι
    charMap[0x1fd1] = codePointToUTF8(0x03b9); //    # ῒ --> ι
    charMap[0x1fd2] = codePointToUTF8(0x03b9); //    # ΐ --> ι
    charMap[0x1fd3] = codePointToUTF8(0x03b9); //    # ῖ --> ι
    charMap[0x1fd6] = codePointToUTF8(0x03b9); //    # ῗ --> ι
    charMap[0x1fd7] = codePointToUTF8(0x03b9); //    # Ῐ --> ι
    charMap[0x1fd8] = codePointToUTF8(0x03b9); //    # Ῑ --> ι
    charMap[0x1fd9] = codePointToUTF8(0x03b9); //    # Ὶ --> ι
    charMap[0x1fda] = codePointToUTF8(0x03b9); //    # Ί --> ι
    charMap[0x1fdb] = codePointToUTF8(0x03b9); //    # ῝ --> ῾
    charMap[0x1fdd] = codePointToUTF8(0x1ffe); //    # ῞ --> ῾
    charMap[0x1fde] = codePointToUTF8(0x1ffe); //    # ῟ --> ῾
    charMap[0x1fdf] = codePointToUTF8(0x1ffe); //    # ῠ --> υ
    charMap[0x1fe0] = codePointToUTF8(0x03c5); //    # ῡ --> υ
    charMap[0x1fe1] = codePointToUTF8(0x03c5); //    # ῢ --> υ
    charMap[0x1fe2] = codePointToUTF8(0x03c5); //    # ΰ --> υ
    charMap[0x1fe3] = codePointToUTF8(0x03c5); //    # ῤ --> ρ
    charMap[0x1fe4] = codePointToUTF8(0x03c1); //    # ῥ --> ρ
    charMap[0x1fe5] = codePointToUTF8(0x03c1); //    # ῦ --> υ
    charMap[0x1fe6] = codePointToUTF8(0x03c5); //    # ῧ --> υ
    charMap[0x1fe7] = codePointToUTF8(0x03c5); //    # Ῠ --> υ
    charMap[0x1fe8] = codePointToUTF8(0x03c5); //    # Ῡ --> υ
    charMap[0x1fe9] = codePointToUTF8(0x03c5); //    # Ὺ --> υ
    charMap[0x1fea] = codePointToUTF8(0x03c5); //    # Ύ --> υ
    charMap[0x1feb] = codePointToUTF8(0x03c5); //    # Ῥ --> ρ
    charMap[0x1fec] = codePointToUTF8(0x03c1); //    # ῭ --> ¨
    charMap[0x1fed] = codePointToUTF8(0x00a8); //    # ΅ --> ¨
    charMap[0x1fee] = codePointToUTF8(0x00a8); //    # ῲ --> ω
    charMap[0x1ff2] = codePointToUTF8(0x03c9); //    # ῳ --> ω
    charMap[0x1ff3] = codePointToUTF8(0x03c9); //    # ῴ --> ω
    charMap[0x1ff4] = codePointToUTF8(0x03c9); //    # ῶ --> ω
    charMap[0x1ff6] = codePointToUTF8(0x03c9); //    # ῷ --> ω
    charMap[0x1ff7] = codePointToUTF8(0x03c9); //    # Ὸ --> ο
    charMap[0x1ff8] = codePointToUTF8(0x03bf); //    # Ό --> ο
    charMap[0x1ff9] = codePointToUTF8(0x03bf); //    # Ὼ --> ω
    charMap[0x1ffa] = codePointToUTF8(0x03c9); //    # Ώ --> ω
    charMap[0x1ffb] = codePointToUTF8(0x03c9); //    # ῼ --> ω
    charMap[0x1ffc] = codePointToUTF8(0x03c9); //    # Ω --> ω
    charMap[0x2126] = codePointToUTF8(0x03c9); //    # K --> k
    charMap[0x212a] = codePointToUTF8(0x006b); //    # Å --> a
    charMap[0x212b] = codePointToUTF8(0x0061); //    # Ⅎ --> ⅎ
    charMap[0x2132] = codePointToUTF8(0x214e); //    # Ⅰ --> ⅰ
    charMap[0x2160] = codePointToUTF8(0x2170); //    # Ⅱ --> ⅱ
    charMap[0x2161] = codePointToUTF8(0x2171); //    # Ⅲ --> ⅲ
    charMap[0x2162] = codePointToUTF8(0x2172); //    # Ⅳ --> ⅳ
    charMap[0x2163] = codePointToUTF8(0x2173); //    # Ⅴ --> ⅴ
    charMap[0x2164] = codePointToUTF8(0x2174); //    # Ⅵ --> ⅵ
    charMap[0x2165] = codePointToUTF8(0x2175); //    # Ⅶ --> ⅶ
    charMap[0x2166] = codePointToUTF8(0x2176); //    # Ⅷ --> ⅷ
    charMap[0x2167] = codePointToUTF8(0x2177); //    # Ⅸ --> ⅸ
    charMap[0x2168] = codePointToUTF8(0x2178); //    # Ⅹ --> ⅹ
    charMap[0x2169] = codePointToUTF8(0x2179); //    # Ⅺ --> ⅺ
    charMap[0x216a] = codePointToUTF8(0x217a); //    # Ⅻ --> ⅻ
    charMap[0x216b] = codePointToUTF8(0x217b); //    # Ⅼ --> ⅼ
    charMap[0x216c] = codePointToUTF8(0x217c); //    # Ⅽ --> ⅽ
    charMap[0x216d] = codePointToUTF8(0x217d); //    # Ⅾ --> ⅾ
    charMap[0x216e] = codePointToUTF8(0x217e); //    # Ⅿ --> ⅿ
    charMap[0x216f] = codePointToUTF8(0x217f); //    # Ↄ --> ↄ
    charMap[0x2183] = codePointToUTF8(0x2184); //    # ↚ --> ←
    charMap[0x219a] = codePointToUTF8(0x2190); //    # ↛ --> →
    charMap[0x219b] = codePointToUTF8(0x2192); //    # ↮ --> ↔
    charMap[0x21ae] = codePointToUTF8(0x2194); //    # ⇍ --> ⇐
    charMap[0x21cd] = codePointToUTF8(0x21d0); //    # ⇎ --> ⇔
    charMap[0x21ce] = codePointToUTF8(0x21d4); //    # ⇏ --> ⇒
    charMap[0x21cf] = codePointToUTF8(0x21d2); //    # ∄ --> ∃
    charMap[0x2204] = codePointToUTF8(0x2203); //    # ∉ --> ∈
    charMap[0x2209] = codePointToUTF8(0x2208); //    # ∌ --> ∋
    charMap[0x220c] = codePointToUTF8(0x220b); //    # ∤ --> ∣
    charMap[0x2224] = codePointToUTF8(0x2223); //    # ∦ --> ∥
    charMap[0x2226] = codePointToUTF8(0x2225); //    # ≁ --> ∼
    charMap[0x2241] = codePointToUTF8(0x223c); //    # ≄ --> ≃
    charMap[0x2244] = codePointToUTF8(0x2243); //    # ≇ --> ≅
    charMap[0x2247] = codePointToUTF8(0x2245); //    # ≉ --> ≈
    charMap[0x2249] = codePointToUTF8(0x2248); //    # ≠ --> =
    charMap[0x2260] = codePointToUTF8(0x003d); //    # ≢ --> ≡
    charMap[0x2262] = codePointToUTF8(0x2261); //    # ≭ --> ≍
    charMap[0x226d] = codePointToUTF8(0x224d); //    # ≮ --> <
    charMap[0x226e] = codePointToUTF8(0x003c); //    # ≯ --> >
    charMap[0x226f] = codePointToUTF8(0x003e); //    # ≰ --> ≤
    charMap[0x2270] = codePointToUTF8(0x2264); //    # ≱ --> ≥
    charMap[0x2271] = codePointToUTF8(0x2265); //    # ≴ --> ≲
    charMap[0x2274] = codePointToUTF8(0x2272); //    # ≵ --> ≳
    charMap[0x2275] = codePointToUTF8(0x2273); //    # ≸ --> ≶
    charMap[0x2278] = codePointToUTF8(0x2276); //    # ≹ --> ≷
    charMap[0x2279] = codePointToUTF8(0x2277); //    # ⊀ --> ≺
    charMap[0x2280] = codePointToUTF8(0x227a); //    # ⊁ --> ≻
    charMap[0x2281] = codePointToUTF8(0x227b); //    # ⊄ --> ⊂
    charMap[0x2284] = codePointToUTF8(0x2282); //    # ⊅ --> ⊃
    charMap[0x2285] = codePointToUTF8(0x2283); //    # ⊈ --> ⊆
    charMap[0x2288] = codePointToUTF8(0x2286); //    # ⊉ --> ⊇
    charMap[0x2289] = codePointToUTF8(0x2287); //    # ⊬ --> ⊢
    charMap[0x22ac] = codePointToUTF8(0x22a2); //    # ⊭ --> ⊨
    charMap[0x22ad] = codePointToUTF8(0x22a8); //    # ⊮ --> ⊩
    charMap[0x22ae] = codePointToUTF8(0x22a9); //    # ⊯ --> ⊫
    charMap[0x22af] = codePointToUTF8(0x22ab); //    # ⋠ --> ≼
    charMap[0x22e0] = codePointToUTF8(0x227c); //    # ⋡ --> ≽
    charMap[0x22e1] = codePointToUTF8(0x227d); //    # ⋢ --> ⊑
    charMap[0x22e2] = codePointToUTF8(0x2291); //    # ⋣ --> ⊒
    charMap[0x22e3] = codePointToUTF8(0x2292); //    # ⋪ --> ⊲
    charMap[0x22ea] = codePointToUTF8(0x22b2); //    # ⋫ --> ⊳
    charMap[0x22eb] = codePointToUTF8(0x22b3); //    # ⋬ --> ⊴
    charMap[0x22ec] = codePointToUTF8(0x22b4); //    # ⋭ --> ⊵
    charMap[0x22ed] = codePointToUTF8(0x22b5); //    # Ⓐ --> ⓐ
    charMap[0x24b6] = codePointToUTF8(0x24d0); //    # Ⓑ --> ⓑ
    charMap[0x24b7] = codePointToUTF8(0x24d1); //    # Ⓒ --> ⓒ
    charMap[0x24b8] = codePointToUTF8(0x24d2); //    # Ⓓ --> ⓓ
    charMap[0x24b9] = codePointToUTF8(0x24d3); //    # Ⓔ --> ⓔ
    charMap[0x24ba] = codePointToUTF8(0x24d4); //    # Ⓕ --> ⓕ
    charMap[0x24bb] = codePointToUTF8(0x24d5); //    # Ⓖ --> ⓖ
    charMap[0x24bc] = codePointToUTF8(0x24d6); //    # Ⓗ --> ⓗ
    charMap[0x24bd] = codePointToUTF8(0x24d7); //    # Ⓘ --> ⓘ
    charMap[0x24be] = codePointToUTF8(0x24d8); //    # Ⓙ --> ⓙ
    charMap[0x24bf] = codePointToUTF8(0x24d9); //    # Ⓚ --> ⓚ
    charMap[0x24c0] = codePointToUTF8(0x24da); //    # Ⓛ --> ⓛ
    charMap[0x24c1] = codePointToUTF8(0x24db); //    # Ⓜ --> ⓜ
    charMap[0x24c2] = codePointToUTF8(0x24dc); //    # Ⓝ --> ⓝ
    charMap[0x24c3] = codePointToUTF8(0x24dd); //    # Ⓞ --> ⓞ
    charMap[0x24c4] = codePointToUTF8(0x24de); //    # Ⓟ --> ⓟ
    charMap[0x24c5] = codePointToUTF8(0x24df); //    # Ⓠ --> ⓠ
    charMap[0x24c6] = codePointToUTF8(0x24e0); //    # Ⓡ --> ⓡ
    charMap[0x24c7] = codePointToUTF8(0x24e1); //    # Ⓢ --> ⓢ
    charMap[0x24c8] = codePointToUTF8(0x24e2); //    # Ⓣ --> ⓣ
    charMap[0x24c9] = codePointToUTF8(0x24e3); //    # Ⓤ --> ⓤ
    charMap[0x24ca] = codePointToUTF8(0x24e4); //    # Ⓥ --> ⓥ
    charMap[0x24cb] = codePointToUTF8(0x24e5); //    # Ⓦ --> ⓦ
    charMap[0x24cc] = codePointToUTF8(0x24e6); //    # Ⓧ --> ⓧ
    charMap[0x24cd] = codePointToUTF8(0x24e7); //    # Ⓨ --> ⓨ
    charMap[0x24ce] = codePointToUTF8(0x24e8); //    # Ⓩ --> ⓩ
    charMap[0x24cf] = codePointToUTF8(0x24e9); //    # ⫝̸ --> ⫝
    charMap[0x2adc] = codePointToUTF8(0x2add); //    # Ⰰ --> ⰰ
    charMap[0x2c00] = codePointToUTF8(0x2c30); //    # Ⰱ --> ⰱ
    charMap[0x2c01] = codePointToUTF8(0x2c31); //    # Ⰲ --> ⰲ
    charMap[0x2c02] = codePointToUTF8(0x2c32); //    # Ⰳ --> ⰳ
    charMap[0x2c03] = codePointToUTF8(0x2c33); //    # Ⰴ --> ⰴ
    charMap[0x2c04] = codePointToUTF8(0x2c34); //    # Ⰵ --> ⰵ
    charMap[0x2c05] = codePointToUTF8(0x2c35); //    # Ⰶ --> ⰶ
    charMap[0x2c06] = codePointToUTF8(0x2c36); //    # Ⰷ --> ⰷ
    charMap[0x2c07] = codePointToUTF8(0x2c37); //    # Ⰸ --> ⰸ
    charMap[0x2c08] = codePointToUTF8(0x2c38); //    # Ⰹ --> ⰹ
    charMap[0x2c09] = codePointToUTF8(0x2c39); //    # Ⰺ --> ⰺ
    charMap[0x2c0a] = codePointToUTF8(0x2c3a); //    # Ⰻ --> ⰻ
    charMap[0x2c0b] = codePointToUTF8(0x2c3b); //    # Ⰼ --> ⰼ
    charMap[0x2c0c] = codePointToUTF8(0x2c3c); //    # Ⰽ --> ⰽ
    charMap[0x2c0d] = codePointToUTF8(0x2c3d); //    # Ⰾ --> ⰾ
    charMap[0x2c0e] = codePointToUTF8(0x2c3e); //    # Ⰿ --> ⰿ
    charMap[0x2c0f] = codePointToUTF8(0x2c3f); //    # Ⱀ --> ⱀ
    charMap[0x2c10] = codePointToUTF8(0x2c40); //    # Ⱁ --> ⱁ
    charMap[0x2c11] = codePointToUTF8(0x2c41); //    # Ⱂ --> ⱂ
    charMap[0x2c12] = codePointToUTF8(0x2c42); //    # Ⱃ --> ⱃ
    charMap[0x2c13] = codePointToUTF8(0x2c43); //    # Ⱄ --> ⱄ
    charMap[0x2c14] = codePointToUTF8(0x2c44); //    # Ⱅ --> ⱅ
    charMap[0x2c15] = codePointToUTF8(0x2c45); //    # Ⱆ --> ⱆ
    charMap[0x2c16] = codePointToUTF8(0x2c46); //    # Ⱇ --> ⱇ
    charMap[0x2c17] = codePointToUTF8(0x2c47); //    # Ⱈ --> ⱈ
    charMap[0x2c18] = codePointToUTF8(0x2c48); //    # Ⱉ --> ⱉ
    charMap[0x2c19] = codePointToUTF8(0x2c49); //    # Ⱊ --> ⱊ
    charMap[0x2c1a] = codePointToUTF8(0x2c4a); //    # Ⱋ --> ⱋ
    charMap[0x2c1b] = codePointToUTF8(0x2c4b); //    # Ⱌ --> ⱌ
    charMap[0x2c1c] = codePointToUTF8(0x2c4c); //    # Ⱍ --> ⱍ
    charMap[0x2c1d] = codePointToUTF8(0x2c4d); //    # Ⱎ --> ⱎ
    charMap[0x2c1e] = codePointToUTF8(0x2c4e); //    # Ⱏ --> ⱏ
    charMap[0x2c1f] = codePointToUTF8(0x2c4f); //    # Ⱐ --> ⱐ
    charMap[0x2c20] = codePointToUTF8(0x2c50); //    # Ⱑ --> ⱑ
    charMap[0x2c21] = codePointToUTF8(0x2c51); //    # Ⱒ --> ⱒ
    charMap[0x2c22] = codePointToUTF8(0x2c52); //    # Ⱓ --> ⱓ
    charMap[0x2c23] = codePointToUTF8(0x2c53); //    # Ⱔ --> ⱔ
    charMap[0x2c24] = codePointToUTF8(0x2c54); //    # Ⱕ --> ⱕ
    charMap[0x2c25] = codePointToUTF8(0x2c55); //    # Ⱖ --> ⱖ
    charMap[0x2c26] = codePointToUTF8(0x2c56); //    # Ⱗ --> ⱗ
    charMap[0x2c27] = codePointToUTF8(0x2c57); //    # Ⱘ --> ⱘ
    charMap[0x2c28] = codePointToUTF8(0x2c58); //    # Ⱙ --> ⱙ
    charMap[0x2c29] = codePointToUTF8(0x2c59); //    # Ⱚ --> ⱚ
    charMap[0x2c2a] = codePointToUTF8(0x2c5a); //    # Ⱛ --> ⱛ
    charMap[0x2c2b] = codePointToUTF8(0x2c5b); //    # Ⱜ --> ⱜ
    charMap[0x2c2c] = codePointToUTF8(0x2c5c); //    # Ⱝ --> ⱝ
    charMap[0x2c2d] = codePointToUTF8(0x2c5d); //    # Ⱞ --> ⱞ
    charMap[0x2c2e] = codePointToUTF8(0x2c5e); //    # Ⱡ --> ⱡ
    charMap[0x2c60] = codePointToUTF8(0x2c61); //    # Ɫ --> ɫ
    charMap[0x2c62] = codePointToUTF8(0x026b); //    # Ᵽ --> ᵽ
    charMap[0x2c63] = codePointToUTF8(0x1d7d); //    # Ɽ --> ɽ
    charMap[0x2c64] = codePointToUTF8(0x027d); //    # Ⱨ --> ⱨ
    charMap[0x2c67] = codePointToUTF8(0x2c68); //    # Ⱪ --> ⱪ
    charMap[0x2c69] = codePointToUTF8(0x2c6a); //    # Ⱬ --> ⱬ
    charMap[0x2c6b] = codePointToUTF8(0x2c6c); //    # Ɑ --> ɑ
    charMap[0x2c6d] = codePointToUTF8(0x0251); //    # Ɱ --> ɱ
    charMap[0x2c6e] = codePointToUTF8(0x0271); //    # Ɐ --> ɐ
    charMap[0x2c6f] = codePointToUTF8(0x0250); //    # Ɒ --> ɒ
    charMap[0x2c70] = codePointToUTF8(0x0252); //    # Ⱳ --> ⱳ
    charMap[0x2c72] = codePointToUTF8(0x2c73); //    # Ⱶ --> ⱶ
    charMap[0x2c75] = codePointToUTF8(0x2c76); //    # Ȿ --> ȿ
    charMap[0x2c7e] = codePointToUTF8(0x023f); //    # Ɀ --> ɀ
    charMap[0x2c7f] = codePointToUTF8(0x0240); //    # Ⲁ --> ⲁ
    charMap[0x2c80] = codePointToUTF8(0x2c81); //    # Ⲃ --> ⲃ
    charMap[0x2c82] = codePointToUTF8(0x2c83); //    # Ⲅ --> ⲅ
    charMap[0x2c84] = codePointToUTF8(0x2c85); //    # Ⲇ --> ⲇ
    charMap[0x2c86] = codePointToUTF8(0x2c87); //    # Ⲉ --> ⲉ
    charMap[0x2c88] = codePointToUTF8(0x2c89); //    # Ⲋ --> ⲋ
    charMap[0x2c8a] = codePointToUTF8(0x2c8b); //    # Ⲍ --> ⲍ
    charMap[0x2c8c] = codePointToUTF8(0x2c8d); //    # Ⲏ --> ⲏ
    charMap[0x2c8e] = codePointToUTF8(0x2c8f); //    # Ⲑ --> ⲑ
    charMap[0x2c90] = codePointToUTF8(0x2c91); //    # Ⲓ --> ⲓ
    charMap[0x2c92] = codePointToUTF8(0x2c93); //    # Ⲕ --> ⲕ
    charMap[0x2c94] = codePointToUTF8(0x2c95); //    # Ⲗ --> ⲗ
    charMap[0x2c96] = codePointToUTF8(0x2c97); //    # Ⲙ --> ⲙ
    charMap[0x2c98] = codePointToUTF8(0x2c99); //    # Ⲛ --> ⲛ
    charMap[0x2c9a] = codePointToUTF8(0x2c9b); //    # Ⲝ --> ⲝ
    charMap[0x2c9c] = codePointToUTF8(0x2c9d); //    # Ⲟ --> ⲟ
    charMap[0x2c9e] = codePointToUTF8(0x2c9f); //    # Ⲡ --> ⲡ
    charMap[0x2ca0] = codePointToUTF8(0x2ca1); //    # Ⲣ --> ⲣ
    charMap[0x2ca2] = codePointToUTF8(0x2ca3); //    # Ⲥ --> ⲥ
    charMap[0x2ca4] = codePointToUTF8(0x2ca5); //    # Ⲧ --> ⲧ
    charMap[0x2ca6] = codePointToUTF8(0x2ca7); //    # Ⲩ --> ⲩ
    charMap[0x2ca8] = codePointToUTF8(0x2ca9); //    # Ⲫ --> ⲫ
    charMap[0x2caa] = codePointToUTF8(0x2cab); //    # Ⲭ --> ⲭ
    charMap[0x2cac] = codePointToUTF8(0x2cad); //    # Ⲯ --> ⲯ
    charMap[0x2cae] = codePointToUTF8(0x2caf); //    # Ⲱ --> ⲱ
    charMap[0x2cb0] = codePointToUTF8(0x2cb1); //    # Ⲳ --> ⲳ
    charMap[0x2cb2] = codePointToUTF8(0x2cb3); //    # Ⲵ --> ⲵ
    charMap[0x2cb4] = codePointToUTF8(0x2cb5); //    # Ⲷ --> ⲷ
    charMap[0x2cb6] = codePointToUTF8(0x2cb7); //    # Ⲹ --> ⲹ
    charMap[0x2cb8] = codePointToUTF8(0x2cb9); //    # Ⲻ --> ⲻ
    charMap[0x2cba] = codePointToUTF8(0x2cbb); //    # Ⲽ --> ⲽ
    charMap[0x2cbc] = codePointToUTF8(0x2cbd); //    # Ⲿ --> ⲿ
    charMap[0x2cbe] = codePointToUTF8(0x2cbf); //    # Ⳁ --> ⳁ
    charMap[0x2cc0] = codePointToUTF8(0x2cc1); //    # Ⳃ --> ⳃ
    charMap[0x2cc2] = codePointToUTF8(0x2cc3); //    # Ⳅ --> ⳅ
    charMap[0x2cc4] = codePointToUTF8(0x2cc5); //    # Ⳇ --> ⳇ
    charMap[0x2cc6] = codePointToUTF8(0x2cc7); //    # Ⳉ --> ⳉ
    charMap[0x2cc8] = codePointToUTF8(0x2cc9); //    # Ⳋ --> ⳋ
    charMap[0x2cca] = codePointToUTF8(0x2ccb); //    # Ⳍ --> ⳍ
    charMap[0x2ccc] = codePointToUTF8(0x2ccd); //    # Ⳏ --> ⳏ
    charMap[0x2cce] = codePointToUTF8(0x2ccf); //    # Ⳑ --> ⳑ
    charMap[0x2cd0] = codePointToUTF8(0x2cd1); //    # Ⳓ --> ⳓ
    charMap[0x2cd2] = codePointToUTF8(0x2cd3); //    # Ⳕ --> ⳕ
    charMap[0x2cd4] = codePointToUTF8(0x2cd5); //    # Ⳗ --> ⳗ
    charMap[0x2cd6] = codePointToUTF8(0x2cd7); //    # Ⳙ --> ⳙ
    charMap[0x2cd8] = codePointToUTF8(0x2cd9); //    # Ⳛ --> ⳛ
    charMap[0x2cda] = codePointToUTF8(0x2cdb); //    # Ⳝ --> ⳝ
    charMap[0x2cdc] = codePointToUTF8(0x2cdd); //    # Ⳟ --> ⳟ
    charMap[0x2cde] = codePointToUTF8(0x2cdf); //    # Ⳡ --> ⳡ
    charMap[0x2ce0] = codePointToUTF8(0x2ce1); //    # Ⳣ --> ⳣ
    charMap[0x2ce2] = codePointToUTF8(0x2ce3); //    # Ⳬ --> ⳬ
    charMap[0x2ceb] = codePointToUTF8(0x2cec); //    # Ⳮ --> ⳮ
    charMap[0x2ced] = codePointToUTF8(0x2cee); //    # Ⳳ --> ⳳ
    charMap[0x2cf2] = codePointToUTF8(0x2cf3); //    # が --> か
    charMap[0x304c] = codePointToUTF8(0x304b); //    # ぎ --> き
    charMap[0x304e] = codePointToUTF8(0x304d); //    # ぐ --> く
    charMap[0x3050] = codePointToUTF8(0x304f); //    # げ --> け
    charMap[0x3052] = codePointToUTF8(0x3051); //    # ご --> こ
    charMap[0x3054] = codePointToUTF8(0x3053); //    # ざ --> さ
    charMap[0x3056] = codePointToUTF8(0x3055); //    # じ --> し
    charMap[0x3058] = codePointToUTF8(0x3057); //    # ず --> す
    charMap[0x305a] = codePointToUTF8(0x3059); //    # ぜ --> せ
    charMap[0x305c] = codePointToUTF8(0x305b); //    # ぞ --> そ
    charMap[0x305e] = codePointToUTF8(0x305d); //    # だ --> た
    charMap[0x3060] = codePointToUTF8(0x305f); //    # ぢ --> ち
    charMap[0x3062] = codePointToUTF8(0x3061); //    # づ --> つ
    charMap[0x3065] = codePointToUTF8(0x3064); //    # で --> て
    charMap[0x3067] = codePointToUTF8(0x3066); //    # ど --> と
    charMap[0x3069] = codePointToUTF8(0x3068); //    # ば --> は
    charMap[0x3070] = codePointToUTF8(0x306f); //    # ぱ --> は
    charMap[0x3071] = codePointToUTF8(0x306f); //    # び --> ひ
    charMap[0x3073] = codePointToUTF8(0x3072); //    # ぴ --> ひ
    charMap[0x3074] = codePointToUTF8(0x3072); //    # ぶ --> ふ
    charMap[0x3076] = codePointToUTF8(0x3075); //    # ぷ --> ふ
    charMap[0x3077] = codePointToUTF8(0x3075); //    # べ --> へ
    charMap[0x3079] = codePointToUTF8(0x3078); //    # ぺ --> へ
    charMap[0x307a] = codePointToUTF8(0x3078); //    # ぼ --> ほ
    charMap[0x307c] = codePointToUTF8(0x307b); //    # ぽ --> ほ
    charMap[0x307d] = codePointToUTF8(0x307b); //    # ゔ --> う
    charMap[0x3094] = codePointToUTF8(0x3046); //    # ゞ --> ゝ
    charMap[0x309e] = codePointToUTF8(0x309d); //    # ガ --> カ
    charMap[0x30ac] = codePointToUTF8(0x30ab); //    # ギ --> キ
    charMap[0x30ae] = codePointToUTF8(0x30ad); //    # グ --> ク
    charMap[0x30b0] = codePointToUTF8(0x30af); //    # ゲ --> ケ
    charMap[0x30b2] = codePointToUTF8(0x30b1); //    # ゴ --> コ
    charMap[0x30b4] = codePointToUTF8(0x30b3); //    # ザ --> サ
    charMap[0x30b6] = codePointToUTF8(0x30b5); //    # ジ --> シ
    charMap[0x30b8] = codePointToUTF8(0x30b7); //    # ズ --> ス
    charMap[0x30ba] = codePointToUTF8(0x30b9); //    # ゼ --> セ
    charMap[0x30bc] = codePointToUTF8(0x30bb); //    # ゾ --> ソ
    charMap[0x30be] = codePointToUTF8(0x30bd); //    # ダ --> タ
    charMap[0x30c0] = codePointToUTF8(0x30bf); //    # ヂ --> チ
    charMap[0x30c2] = codePointToUTF8(0x30c1); //    # ヅ --> ツ
    charMap[0x30c5] = codePointToUTF8(0x30c4); //    # デ --> テ
    charMap[0x30c7] = codePointToUTF8(0x30c6); //    # ド --> ト
    charMap[0x30c9] = codePointToUTF8(0x30c8); //    # バ --> ハ
    charMap[0x30d0] = codePointToUTF8(0x30cf); //    # パ --> ハ
    charMap[0x30d1] = codePointToUTF8(0x30cf); //    # ビ --> ヒ
    charMap[0x30d3] = codePointToUTF8(0x30d2); //    # ピ --> ヒ
    charMap[0x30d4] = codePointToUTF8(0x30d2); //    # ブ --> フ
    charMap[0x30d6] = codePointToUTF8(0x30d5); //    # プ --> フ
    charMap[0x30d7] = codePointToUTF8(0x30d5); //    # ベ --> ヘ
    charMap[0x30d9] = codePointToUTF8(0x30d8); //    # ペ --> ヘ
    charMap[0x30da] = codePointToUTF8(0x30d8); //    # ボ --> ホ
    charMap[0x30dc] = codePointToUTF8(0x30db); //    # ポ --> ホ
    charMap[0x30dd] = codePointToUTF8(0x30db); //    # ヴ --> ウ
    charMap[0x30f4] = codePointToUTF8(0x30a6); //    # ヷ --> ワ
    charMap[0x30f7] = codePointToUTF8(0x30ef); //    # ヸ --> ヰ
    charMap[0x30f8] = codePointToUTF8(0x30f0); //    # ヹ --> ヱ
    charMap[0x30f9] = codePointToUTF8(0x30f1); //    # ヺ --> ヲ
    charMap[0x30fa] = codePointToUTF8(0x30f2); //    # ヾ --> ヽ
    charMap[0x30fe] = codePointToUTF8(0x30fd); //    # Ꙁ --> ꙁ
    charMap[0xa640] = codePointToUTF8(0xa641); //    # Ꙃ --> ꙃ
    charMap[0xa642] = codePointToUTF8(0xa643); //    # Ꙅ --> ꙅ
    charMap[0xa644] = codePointToUTF8(0xa645); //    # Ꙇ --> ꙇ
    charMap[0xa646] = codePointToUTF8(0xa647); //    # Ꙉ --> ꙉ
    charMap[0xa648] = codePointToUTF8(0xa649); //    # Ꙋ --> ꙋ
    charMap[0xa64a] = codePointToUTF8(0xa64b); //    # Ꙍ --> ꙍ
    charMap[0xa64c] = codePointToUTF8(0xa64d); //    # Ꙏ --> ꙏ
    charMap[0xa64e] = codePointToUTF8(0xa64f); //    # Ꙑ --> ꙑ
    charMap[0xa650] = codePointToUTF8(0xa651); //    # Ꙓ --> ꙓ
    charMap[0xa652] = codePointToUTF8(0xa653); //    # Ꙕ --> ꙕ
    charMap[0xa654] = codePointToUTF8(0xa655); //    # Ꙗ --> ꙗ
    charMap[0xa656] = codePointToUTF8(0xa657); //    # Ꙙ --> ꙙ
    charMap[0xa658] = codePointToUTF8(0xa659); //    # Ꙛ --> ꙛ
    charMap[0xa65a] = codePointToUTF8(0xa65b); //    # Ꙝ --> ꙝ
    charMap[0xa65c] = codePointToUTF8(0xa65d); //    # Ꙟ --> ꙟ
    charMap[0xa65e] = codePointToUTF8(0xa65f); //    # Ꙡ --> ꙡ
    charMap[0xa660] = codePointToUTF8(0xa661); //    # Ꙣ --> ꙣ
    charMap[0xa662] = codePointToUTF8(0xa663); //    # Ꙥ --> ꙥ
    charMap[0xa664] = codePointToUTF8(0xa665); //    # Ꙧ --> ꙧ
    charMap[0xa666] = codePointToUTF8(0xa667); //    # Ꙩ --> ꙩ
    charMap[0xa668] = codePointToUTF8(0xa669); //    # Ꙫ --> ꙫ
    charMap[0xa66a] = codePointToUTF8(0xa66b); //    # Ꙭ --> ꙭ
    charMap[0xa66c] = codePointToUTF8(0xa66d); //    # Ꚁ --> ꚁ
    charMap[0xa680] = codePointToUTF8(0xa681); //    # Ꚃ --> ꚃ
    charMap[0xa682] = codePointToUTF8(0xa683); //    # Ꚅ --> ꚅ
    charMap[0xa684] = codePointToUTF8(0xa685); //    # Ꚇ --> ꚇ
    charMap[0xa686] = codePointToUTF8(0xa687); //    # Ꚉ --> ꚉ
    charMap[0xa688] = codePointToUTF8(0xa689); //    # Ꚋ --> ꚋ
    charMap[0xa68a] = codePointToUTF8(0xa68b); //    # Ꚍ --> ꚍ
    charMap[0xa68c] = codePointToUTF8(0xa68d); //    # Ꚏ --> ꚏ
    charMap[0xa68e] = codePointToUTF8(0xa68f); //    # Ꚑ --> ꚑ
    charMap[0xa690] = codePointToUTF8(0xa691); //    # Ꚓ --> ꚓ
    charMap[0xa692] = codePointToUTF8(0xa693); //    # Ꚕ --> ꚕ
    charMap[0xa694] = codePointToUTF8(0xa695); //    # Ꚗ --> ꚗ
    charMap[0xa696] = codePointToUTF8(0xa697); //    # Ꚙ --> ꚙ
    charMap[0xa698] = codePointToUTF8(0xa699); //    # Ꚛ --> ꚛ
    charMap[0xa69a] = codePointToUTF8(0xa69b); //    # Ꜣ --> ꜣ
    charMap[0xa722] = codePointToUTF8(0xa723); //    # Ꜥ --> ꜥ
    charMap[0xa724] = codePointToUTF8(0xa725); //    # Ꜧ --> ꜧ
    charMap[0xa726] = codePointToUTF8(0xa727); //    # Ꜩ --> ꜩ
    charMap[0xa728] = codePointToUTF8(0xa729); //    # Ꜫ --> ꜫ
    charMap[0xa72a] = codePointToUTF8(0xa72b); //    # Ꜭ --> ꜭ
    charMap[0xa72c] = codePointToUTF8(0xa72d); //    # Ꜯ --> ꜯ
    charMap[0xa72e] = codePointToUTF8(0xa72f); //    # Ꜳ --> ꜳ
    charMap[0xa732] = codePointToUTF8(0xa733); //    # Ꜵ --> ꜵ
    charMap[0xa734] = codePointToUTF8(0xa735); //    # Ꜷ --> ꜷ
    charMap[0xa736] = codePointToUTF8(0xa737); //    # Ꜹ --> ꜹ
    charMap[0xa738] = codePointToUTF8(0xa739); //    # Ꜻ --> ꜻ
    charMap[0xa73a] = codePointToUTF8(0xa73b); //    # Ꜽ --> ꜽ
    charMap[0xa73c] = codePointToUTF8(0xa73d); //    # Ꜿ --> ꜿ
    charMap[0xa73e] = codePointToUTF8(0xa73f); //    # Ꝁ --> ꝁ
    charMap[0xa740] = codePointToUTF8(0xa741); //    # Ꝃ --> ꝃ
    charMap[0xa742] = codePointToUTF8(0xa743); //    # Ꝅ --> ꝅ
    charMap[0xa744] = codePointToUTF8(0xa745); //    # Ꝇ --> ꝇ
    charMap[0xa746] = codePointToUTF8(0xa747); //    # Ꝉ --> ꝉ
    charMap[0xa748] = codePointToUTF8(0xa749); //    # Ꝋ --> ꝋ
    charMap[0xa74a] = codePointToUTF8(0xa74b); //    # Ꝍ --> ꝍ
    charMap[0xa74c] = codePointToUTF8(0xa74d); //    # Ꝏ --> ꝏ
    charMap[0xa74e] = codePointToUTF8(0xa74f); //    # Ꝑ --> ꝑ
    charMap[0xa750] = codePointToUTF8(0xa751); //    # Ꝓ --> ꝓ
    charMap[0xa752] = codePointToUTF8(0xa753); //    # Ꝕ --> ꝕ
    charMap[0xa754] = codePointToUTF8(0xa755); //    # Ꝗ --> ꝗ
    charMap[0xa756] = codePointToUTF8(0xa757); //    # Ꝙ --> ꝙ
    charMap[0xa758] = codePointToUTF8(0xa759); //    # Ꝛ --> ꝛ
    charMap[0xa75a] = codePointToUTF8(0xa75b); //    # Ꝝ --> ꝝ
    charMap[0xa75c] = codePointToUTF8(0xa75d); //    # Ꝟ --> ꝟ
    charMap[0xa75e] = codePointToUTF8(0xa75f); //    # Ꝡ --> ꝡ
    charMap[0xa760] = codePointToUTF8(0xa761); //    # Ꝣ --> ꝣ
    charMap[0xa762] = codePointToUTF8(0xa763); //    # Ꝥ --> ꝥ
    charMap[0xa764] = codePointToUTF8(0xa765); //    # Ꝧ --> ꝧ
    charMap[0xa766] = codePointToUTF8(0xa767); //    # Ꝩ --> ꝩ
    charMap[0xa768] = codePointToUTF8(0xa769); //    # Ꝫ --> ꝫ
    charMap[0xa76a] = codePointToUTF8(0xa76b); //    # Ꝭ --> ꝭ
    charMap[0xa76c] = codePointToUTF8(0xa76d); //    # Ꝯ --> ꝯ
    charMap[0xa76e] = codePointToUTF8(0xa76f); //    # Ꝺ --> ꝺ
    charMap[0xa779] = codePointToUTF8(0xa77a); //    # Ꝼ --> ꝼ
    charMap[0xa77b] = codePointToUTF8(0xa77c); //    # Ᵹ --> ᵹ
    charMap[0xa77d] = codePointToUTF8(0x1d79); //    # Ꝿ --> ꝿ
    charMap[0xa77e] = codePointToUTF8(0xa77f); //    # Ꞁ --> ꞁ
    charMap[0xa780] = codePointToUTF8(0xa781); //    # Ꞃ --> ꞃ
    charMap[0xa782] = codePointToUTF8(0xa783); //    # Ꞅ --> ꞅ
    charMap[0xa784] = codePointToUTF8(0xa785); //    # Ꞇ --> ꞇ
    charMap[0xa786] = codePointToUTF8(0xa787); //    # Ꞌ --> ꞌ
    charMap[0xa78b] = codePointToUTF8(0xa78c); //    # Ɥ --> ɥ
    charMap[0xa78d] = codePointToUTF8(0x0265); //    # Ꞑ --> ꞑ
    charMap[0xa790] = codePointToUTF8(0xa791); //    # Ꞓ --> ꞓ
    charMap[0xa792] = codePointToUTF8(0xa793); //    # Ꞗ --> ꞗ
    charMap[0xa796] = codePointToUTF8(0xa797); //    # Ꞙ --> ꞙ
    charMap[0xa798] = codePointToUTF8(0xa799); //    # Ꞛ --> ꞛ
    charMap[0xa79a] = codePointToUTF8(0xa79b); //    # Ꞝ --> ꞝ
    charMap[0xa79c] = codePointToUTF8(0xa79d); //    # Ꞟ --> ꞟ
    charMap[0xa79e] = codePointToUTF8(0xa79f); //    # Ꞡ --> ꞡ
    charMap[0xa7a0] = codePointToUTF8(0xa7a1); //    # Ꞣ --> ꞣ
    charMap[0xa7a2] = codePointToUTF8(0xa7a3); //    # Ꞥ --> ꞥ
    charMap[0xa7a4] = codePointToUTF8(0xa7a5); //    # Ꞧ --> ꞧ
    charMap[0xa7a6] = codePointToUTF8(0xa7a7); //    # Ꞩ --> ꞩ
    charMap[0xa7a8] = codePointToUTF8(0xa7a9); //    # Ɦ --> ɦ
    charMap[0xa7aa] = codePointToUTF8(0x0266); //    # Ɜ --> ɜ
    charMap[0xa7ab] = codePointToUTF8(0x025c); //    # Ɡ --> ɡ
    charMap[0xa7ac] = codePointToUTF8(0x0261); //    # Ɬ --> ɬ
    charMap[0xa7ad] = codePointToUTF8(0x026c); //    # Ɪ --> ɪ
    charMap[0xa7ae] = codePointToUTF8(0x026a); //    # Ʞ --> ʞ
    charMap[0xa7b0] = codePointToUTF8(0x029e); //    # Ʇ --> ʇ
    charMap[0xa7b1] = codePointToUTF8(0x0287); //    # Ʝ --> ʝ
    charMap[0xa7b2] = codePointToUTF8(0x029d); //    # Ꭓ --> ꭓ
    charMap[0xa7b3] = codePointToUTF8(0xab53); //    # Ꞵ --> ꞵ
    charMap[0xa7b4] = codePointToUTF8(0xa7b5); //    # Ꞷ --> ꞷ
    charMap[0xa7b6] = codePointToUTF8(0xa7b7); //    # יִ --> י
    charMap[0xfb1d] = codePointToUTF8(0x05d9); //    # ײַ --> ײ
    charMap[0xfb1f] = codePointToUTF8(0x05f2); //    # שׁ --> ש
    charMap[0xfb2a] = codePointToUTF8(0x05e9); //    # שׂ --> ש
    charMap[0xfb2b] = codePointToUTF8(0x05e9); //    # שּׁ --> ש
    charMap[0xfb2c] = codePointToUTF8(0x05e9); //    # שּׂ --> ש
    charMap[0xfb2d] = codePointToUTF8(0x05e9); //    # אַ --> א
    charMap[0xfb2e] = codePointToUTF8(0x05d0); //    # אָ --> א
    charMap[0xfb2f] = codePointToUTF8(0x05d0); //    # אּ --> א
    charMap[0xfb30] = codePointToUTF8(0x05d0); //    # בּ --> ב
    charMap[0xfb31] = codePointToUTF8(0x05d1); //    # גּ --> ג
    charMap[0xfb32] = codePointToUTF8(0x05d2); //    # דּ --> ד
    charMap[0xfb33] = codePointToUTF8(0x05d3); //    # הּ --> ה
    charMap[0xfb34] = codePointToUTF8(0x05d4); //    # וּ --> ו
    charMap[0xfb35] = codePointToUTF8(0x05d5); //    # זּ --> ז
    charMap[0xfb36] = codePointToUTF8(0x05d6); //    # טּ --> ט
    charMap[0xfb38] = codePointToUTF8(0x05d8); //    # יּ --> י
    charMap[0xfb39] = codePointToUTF8(0x05d9); //    # ךּ --> ך
    charMap[0xfb3a] = codePointToUTF8(0x05da); //    # כּ --> כ
    charMap[0xfb3b] = codePointToUTF8(0x05db); //    # לּ --> ל
    charMap[0xfb3c] = codePointToUTF8(0x05dc); //    # מּ --> מ
    charMap[0xfb3e] = codePointToUTF8(0x05de); //    # נּ --> נ
    charMap[0xfb40] = codePointToUTF8(0x05e0); //    # סּ --> ס
    charMap[0xfb41] = codePointToUTF8(0x05e1); //    # ףּ --> ף
    charMap[0xfb43] = codePointToUTF8(0x05e3); //    # פּ --> פ
    charMap[0xfb44] = codePointToUTF8(0x05e4); //    # צּ --> צ
    charMap[0xfb46] = codePointToUTF8(0x05e6); //    # קּ --> ק
    charMap[0xfb47] = codePointToUTF8(0x05e7); //    # רּ --> ר
    charMap[0xfb48] = codePointToUTF8(0x05e8); //    # שּ --> ש
    charMap[0xfb49] = codePointToUTF8(0x05e9); //    # תּ --> ת
    charMap[0xfb4a] = codePointToUTF8(0x05ea); //    # וֹ --> ו
    charMap[0xfb4b] = codePointToUTF8(0x05d5); //    # בֿ --> ב
    charMap[0xfb4c] = codePointToUTF8(0x05d1); //    # כֿ --> כ
    charMap[0xfb4d] = codePointToUTF8(0x05db); //    # פֿ --> פ
    charMap[0xfb4e] = codePointToUTF8(0x05e4); //    # Ａ --> ａ
    charMap[0xff21] = codePointToUTF8(0xff41); //    # Ｂ --> ｂ
    charMap[0xff22] = codePointToUTF8(0xff42); //    # Ｃ --> ｃ
    charMap[0xff23] = codePointToUTF8(0xff43); //    # Ｄ --> ｄ
    charMap[0xff24] = codePointToUTF8(0xff44); //    # Ｅ --> ｅ
    charMap[0xff25] = codePointToUTF8(0xff45); //    # Ｆ --> ｆ
    charMap[0xff26] = codePointToUTF8(0xff46); //    # Ｇ --> ｇ
    charMap[0xff27] = codePointToUTF8(0xff47); //    # Ｈ --> ｈ
    charMap[0xff28] = codePointToUTF8(0xff48); //    # Ｉ --> ｉ
    charMap[0xff29] = codePointToUTF8(0xff49); //    # Ｊ --> ｊ
    charMap[0xff2a] = codePointToUTF8(0xff4a); //    # Ｋ --> ｋ
    charMap[0xff2b] = codePointToUTF8(0xff4b); //    # Ｌ --> ｌ
    charMap[0xff2c] = codePointToUTF8(0xff4c); //    # Ｍ --> ｍ
    charMap[0xff2d] = codePointToUTF8(0xff4d); //    # Ｎ --> ｎ
    charMap[0xff2e] = codePointToUTF8(0xff4e); //    # Ｏ --> ｏ
    charMap[0xff2f] = codePointToUTF8(0xff4f); //    # Ｐ --> ｐ
    charMap[0xff30] = codePointToUTF8(0xff50); //    # Ｑ --> ｑ
    charMap[0xff31] = codePointToUTF8(0xff51); //    # Ｒ --> ｒ
    charMap[0xff32] = codePointToUTF8(0xff52); //    # Ｓ --> ｓ
    charMap[0xff33] = codePointToUTF8(0xff53); //    # Ｔ --> ｔ
    charMap[0xff34] = codePointToUTF8(0xff54); //    # Ｕ --> ｕ
    charMap[0xff35] = codePointToUTF8(0xff55); //    # Ｖ --> ｖ
    charMap[0xff36] = codePointToUTF8(0xff56); //    # Ｗ --> ｗ
    charMap[0xff37] = codePointToUTF8(0xff57); //    # Ｘ --> ｘ
    charMap[0xff38] = codePointToUTF8(0xff58); //    # Ｙ --> ｙ
    charMap[0xff39] = codePointToUTF8(0xff59); //    # Ｚ --> ｚ
    charMap[0xff3a] = codePointToUTF8(0xff5a); //    # 𐐀 --> 𐐨
    charMap[0x10400] = codePointToUTF8(0x10428); //    # 𐐁 --> 𐐩
    charMap[0x10401] = codePointToUTF8(0x10429); //    # 𐐂 --> 𐐪
    charMap[0x10402] = codePointToUTF8(0x1042a); //    # 𐐃 --> 𐐫
    charMap[0x10403] = codePointToUTF8(0x1042b); //    # 𐐄 --> 𐐬
    charMap[0x10404] = codePointToUTF8(0x1042c); //    # 𐐅 --> 𐐭
    charMap[0x10405] = codePointToUTF8(0x1042d); //    # 𐐆 --> 𐐮
    charMap[0x10406] = codePointToUTF8(0x1042e); //    # 𐐇 --> 𐐯
    charMap[0x10407] = codePointToUTF8(0x1042f); //    # 𐐈 --> 𐐰
    charMap[0x10408] = codePointToUTF8(0x10430); //    # 𐐉 --> 𐐱
    charMap[0x10409] = codePointToUTF8(0x10431); //    # 𐐊 --> 𐐲
    charMap[0x1040a] = codePointToUTF8(0x10432); //    # 𐐋 --> 𐐳
    charMap[0x1040b] = codePointToUTF8(0x10433); //    # 𐐌 --> 𐐴
    charMap[0x1040c] = codePointToUTF8(0x10434); //    # 𐐍 --> 𐐵
    charMap[0x1040d] = codePointToUTF8(0x10435); //    # 𐐎 --> 𐐶
    charMap[0x1040e] = codePointToUTF8(0x10436); //    # 𐐏 --> 𐐷
    charMap[0x1040f] = codePointToUTF8(0x10437); //    # 𐐐 --> 𐐸
    charMap[0x10410] = codePointToUTF8(0x10438); //    # 𐐑 --> 𐐹
    charMap[0x10411] = codePointToUTF8(0x10439); //    # 𐐒 --> 𐐺
    charMap[0x10412] = codePointToUTF8(0x1043a); //    # 𐐓 --> 𐐻
    charMap[0x10413] = codePointToUTF8(0x1043b); //    # 𐐔 --> 𐐼
    charMap[0x10414] = codePointToUTF8(0x1043c); //    # 𐐕 --> 𐐽
    charMap[0x10415] = codePointToUTF8(0x1043d); //    # 𐐖 --> 𐐾
    charMap[0x10416] = codePointToUTF8(0x1043e); //    # 𐐗 --> 𐐿
    charMap[0x10417] = codePointToUTF8(0x1043f); //    # 𐐘 --> 𐑀
    charMap[0x10418] = codePointToUTF8(0x10440); //    # 𐐙 --> 𐑁
    charMap[0x10419] = codePointToUTF8(0x10441); //    # 𐐚 --> 𐑂
    charMap[0x1041a] = codePointToUTF8(0x10442); //    # 𐐛 --> 𐑃
    charMap[0x1041b] = codePointToUTF8(0x10443); //    # 𐐜 --> 𐑄
    charMap[0x1041c] = codePointToUTF8(0x10444); //    # 𐐝 --> 𐑅
    charMap[0x1041d] = codePointToUTF8(0x10445); //    # 𐐞 --> 𐑆
    charMap[0x1041e] = codePointToUTF8(0x10446); //    # 𐐟 --> 𐑇
    charMap[0x1041f] = codePointToUTF8(0x10447); //    # 𐐠 --> 𐑈
    charMap[0x10420] = codePointToUTF8(0x10448); //    # 𐐡 --> 𐑉
    charMap[0x10421] = codePointToUTF8(0x10449); //    # 𐐢 --> 𐑊
    charMap[0x10422] = codePointToUTF8(0x1044a); //    # 𐐣 --> 𐑋
    charMap[0x10423] = codePointToUTF8(0x1044b); //    # 𐐤 --> 𐑌
    charMap[0x10424] = codePointToUTF8(0x1044c); //    # 𐐥 --> 𐑍
    charMap[0x10425] = codePointToUTF8(0x1044d); //    # 𐐦 --> 𐑎
    charMap[0x10426] = codePointToUTF8(0x1044e); //    # 𐐧 --> 𐑏
    charMap[0x10427] = codePointToUTF8(0x1044f); //    # 𐒰 --> 𐓘
    charMap[0x104b0] = codePointToUTF8(0x104d8); //    # 𐒱 --> 𐓙
    charMap[0x104b1] = codePointToUTF8(0x104d9); //    # 𐒲 --> 𐓚
    charMap[0x104b2] = codePointToUTF8(0x104da); //    # 𐒳 --> 𐓛
    charMap[0x104b3] = codePointToUTF8(0x104db); //    # 𐒴 --> 𐓜
    charMap[0x104b4] = codePointToUTF8(0x104dc); //    # 𐒵 --> 𐓝
    charMap[0x104b5] = codePointToUTF8(0x104dd); //    # 𐒶 --> 𐓞
    charMap[0x104b6] = codePointToUTF8(0x104de); //    # 𐒷 --> 𐓟
    charMap[0x104b7] = codePointToUTF8(0x104df); //    # 𐒸 --> 𐓠
    charMap[0x104b8] = codePointToUTF8(0x104e0); //    # 𐒹 --> 𐓡
    charMap[0x104b9] = codePointToUTF8(0x104e1); //    # 𐒺 --> 𐓢
    charMap[0x104ba] = codePointToUTF8(0x104e2); //    # 𐒻 --> 𐓣
    charMap[0x104bb] = codePointToUTF8(0x104e3); //    # 𐒼 --> 𐓤
    charMap[0x104bc] = codePointToUTF8(0x104e4); //    # 𐒽 --> 𐓥
    charMap[0x104bd] = codePointToUTF8(0x104e5); //    # 𐒾 --> 𐓦
    charMap[0x104be] = codePointToUTF8(0x104e6); //    # 𐒿 --> 𐓧
    charMap[0x104bf] = codePointToUTF8(0x104e7); //    # 𐓀 --> 𐓨
    charMap[0x104c0] = codePointToUTF8(0x104e8); //    # 𐓁 --> 𐓩
    charMap[0x104c1] = codePointToUTF8(0x104e9); //    # 𐓂 --> 𐓪
    charMap[0x104c2] = codePointToUTF8(0x104ea); //    # 𐓃 --> 𐓫
    charMap[0x104c3] = codePointToUTF8(0x104eb); //    # 𐓄 --> 𐓬
    charMap[0x104c4] = codePointToUTF8(0x104ec); //    # 𐓅 --> 𐓭
    charMap[0x104c5] = codePointToUTF8(0x104ed); //    # 𐓆 --> 𐓮
    charMap[0x104c6] = codePointToUTF8(0x104ee); //    # 𐓇 --> 𐓯
    charMap[0x104c7] = codePointToUTF8(0x104ef); //    # 𐓈 --> 𐓰
    charMap[0x104c8] = codePointToUTF8(0x104f0); //    # 𐓉 --> 𐓱
    charMap[0x104c9] = codePointToUTF8(0x104f1); //    # 𐓊 --> 𐓲
    charMap[0x104ca] = codePointToUTF8(0x104f2); //    # 𐓋 --> 𐓳
    charMap[0x104cb] = codePointToUTF8(0x104f3); //    # 𐓌 --> 𐓴
    charMap[0x104cc] = codePointToUTF8(0x104f4); //    # 𐓍 --> 𐓵
    charMap[0x104cd] = codePointToUTF8(0x104f5); //    # 𐓎 --> 𐓶
    charMap[0x104ce] = codePointToUTF8(0x104f6); //    # 𐓏 --> 𐓷
    charMap[0x104cf] = codePointToUTF8(0x104f7); //    # 𐓐 --> 𐓸
    charMap[0x104d0] = codePointToUTF8(0x104f8); //    # 𐓑 --> 𐓹
    charMap[0x104d1] = codePointToUTF8(0x104f9); //    # 𐓒 --> 𐓺
    charMap[0x104d2] = codePointToUTF8(0x104fa); //    # 𐓓 --> 𐓻
    charMap[0x104d3] = codePointToUTF8(0x104fb); //    # 𐲀 --> 𐳀
    charMap[0x10c80] = codePointToUTF8(0x10cc0); //    # 𐲁 --> 𐳁
    charMap[0x10c81] = codePointToUTF8(0x10cc1); //    # 𐲂 --> 𐳂
    charMap[0x10c82] = codePointToUTF8(0x10cc2); //    # 𐲃 --> 𐳃
    charMap[0x10c83] = codePointToUTF8(0x10cc3); //    # 𐲄 --> 𐳄
    charMap[0x10c84] = codePointToUTF8(0x10cc4); //    # 𐲅 --> 𐳅
    charMap[0x10c85] = codePointToUTF8(0x10cc5); //    # 𐲆 --> 𐳆
    charMap[0x10c86] = codePointToUTF8(0x10cc6); //    # 𐲇 --> 𐳇
    charMap[0x10c87] = codePointToUTF8(0x10cc7); //    # 𐲈 --> 𐳈
    charMap[0x10c88] = codePointToUTF8(0x10cc8); //    # 𐲉 --> 𐳉
    charMap[0x10c89] = codePointToUTF8(0x10cc9); //    # 𐲊 --> 𐳊
    charMap[0x10c8a] = codePointToUTF8(0x10cca); //    # 𐲋 --> 𐳋
    charMap[0x10c8b] = codePointToUTF8(0x10ccb); //    # 𐲌 --> 𐳌
    charMap[0x10c8c] = codePointToUTF8(0x10ccc); //    # 𐲍 --> 𐳍
    charMap[0x10c8d] = codePointToUTF8(0x10ccd); //    # 𐲎 --> 𐳎
    charMap[0x10c8e] = codePointToUTF8(0x10cce); //    # 𐲏 --> 𐳏
    charMap[0x10c8f] = codePointToUTF8(0x10ccf); //    # 𐲐 --> 𐳐
    charMap[0x10c90] = codePointToUTF8(0x10cd0); //    # 𐲑 --> 𐳑
    charMap[0x10c91] = codePointToUTF8(0x10cd1); //    # 𐲒 --> 𐳒
    charMap[0x10c92] = codePointToUTF8(0x10cd2); //    # 𐲓 --> 𐳓
    charMap[0x10c93] = codePointToUTF8(0x10cd3); //    # 𐲔 --> 𐳔
    charMap[0x10c94] = codePointToUTF8(0x10cd4); //    # 𐲕 --> 𐳕
    charMap[0x10c95] = codePointToUTF8(0x10cd5); //    # 𐲖 --> 𐳖
    charMap[0x10c96] = codePointToUTF8(0x10cd6); //    # 𐲗 --> 𐳗
    charMap[0x10c97] = codePointToUTF8(0x10cd7); //    # 𐲘 --> 𐳘
    charMap[0x10c98] = codePointToUTF8(0x10cd8); //    # 𐲙 --> 𐳙
    charMap[0x10c99] = codePointToUTF8(0x10cd9); //    # 𐲚 --> 𐳚
    charMap[0x10c9a] = codePointToUTF8(0x10cda); //    # 𐲛 --> 𐳛
    charMap[0x10c9b] = codePointToUTF8(0x10cdb); //    # 𐲜 --> 𐳜
    charMap[0x10c9c] = codePointToUTF8(0x10cdc); //    # 𐲝 --> 𐳝
    charMap[0x10c9d] = codePointToUTF8(0x10cdd); //    # 𐲞 --> 𐳞
    charMap[0x10c9e] = codePointToUTF8(0x10cde); //    # 𐲟 --> 𐳟
    charMap[0x10c9f] = codePointToUTF8(0x10cdf); //    # 𐲠 --> 𐳠
    charMap[0x10ca0] = codePointToUTF8(0x10ce0); //    # 𐲡 --> 𐳡
    charMap[0x10ca1] = codePointToUTF8(0x10ce1); //    # 𐲢 --> 𐳢
    charMap[0x10ca2] = codePointToUTF8(0x10ce2); //    # 𐲣 --> 𐳣
    charMap[0x10ca3] = codePointToUTF8(0x10ce3); //    # 𐲤 --> 𐳤
    charMap[0x10ca4] = codePointToUTF8(0x10ce4); //    # 𐲥 --> 𐳥
    charMap[0x10ca5] = codePointToUTF8(0x10ce5); //    # 𐲦 --> 𐳦
    charMap[0x10ca6] = codePointToUTF8(0x10ce6); //    # 𐲧 --> 𐳧
    charMap[0x10ca7] = codePointToUTF8(0x10ce7); //    # 𐲨 --> 𐳨
    charMap[0x10ca8] = codePointToUTF8(0x10ce8); //    # 𐲩 --> 𐳩
    charMap[0x10ca9] = codePointToUTF8(0x10ce9); //    # 𐲪 --> 𐳪
    charMap[0x10caa] = codePointToUTF8(0x10cea); //    # 𐲫 --> 𐳫
    charMap[0x10cab] = codePointToUTF8(0x10ceb); //    # 𐲬 --> 𐳬
    charMap[0x10cac] = codePointToUTF8(0x10cec); //    # 𐲭 --> 𐳭
    charMap[0x10cad] = codePointToUTF8(0x10ced); //    # 𐲮 --> 𐳮
    charMap[0x10cae] = codePointToUTF8(0x10cee); //    # 𐲯 --> 𐳯
    charMap[0x10caf] = codePointToUTF8(0x10cef); //    # 𐲰 --> 𐳰
    charMap[0x10cb0] = codePointToUTF8(0x10cf0); //    # 𐲱 --> 𐳱
    charMap[0x10cb1] = codePointToUTF8(0x10cf1); //    # 𐲲 --> 𐳲
    charMap[0x10cb2] = codePointToUTF8(0x10cf2); //    # 𑂚 --> 𑂙
    charMap[0x1109a] = codePointToUTF8(0x11099); //    # 𑂜 --> 𑂛
    charMap[0x1109c] = codePointToUTF8(0x1109b); //    # 𑂫 --> 𑂥
    charMap[0x110ab] = codePointToUTF8(0x110a5); //    # 𑒻 --> 𑒹
    charMap[0x114bb] = codePointToUTF8(0x114b9); //    # 𑢠 --> 𑣀
    charMap[0x118a0] = codePointToUTF8(0x118c0); //    # 𑢡 --> 𑣁
    charMap[0x118a1] = codePointToUTF8(0x118c1); //    # 𑢢 --> 𑣂
    charMap[0x118a2] = codePointToUTF8(0x118c2); //    # 𑢣 --> 𑣃
    charMap[0x118a3] = codePointToUTF8(0x118c3); //    # 𑢤 --> 𑣄
    charMap[0x118a4] = codePointToUTF8(0x118c4); //    # 𑢥 --> 𑣅
    charMap[0x118a5] = codePointToUTF8(0x118c5); //    # 𑢦 --> 𑣆
    charMap[0x118a6] = codePointToUTF8(0x118c6); //    # 𑢧 --> 𑣇
    charMap[0x118a7] = codePointToUTF8(0x118c7); //    # 𑢨 --> 𑣈
    charMap[0x118a8] = codePointToUTF8(0x118c8); //    # 𑢩 --> 𑣉
    charMap[0x118a9] = codePointToUTF8(0x118c9); //    # 𑢪 --> 𑣊
    charMap[0x118aa] = codePointToUTF8(0x118ca); //    # 𑢫 --> 𑣋
    charMap[0x118ab] = codePointToUTF8(0x118cb); //    # 𑢬 --> 𑣌
    charMap[0x118ac] = codePointToUTF8(0x118cc); //    # 𑢭 --> 𑣍
    charMap[0x118ad] = codePointToUTF8(0x118cd); //    # 𑢮 --> 𑣎
    charMap[0x118ae] = codePointToUTF8(0x118ce); //    # 𑢯 --> 𑣏
    charMap[0x118af] = codePointToUTF8(0x118cf); //    # 𑢰 --> 𑣐
    charMap[0x118b0] = codePointToUTF8(0x118d0); //    # 𑢱 --> 𑣑
    charMap[0x118b1] = codePointToUTF8(0x118d1); //    # 𑢲 --> 𑣒
    charMap[0x118b2] = codePointToUTF8(0x118d2); //    # 𑢳 --> 𑣓
    charMap[0x118b3] = codePointToUTF8(0x118d3); //    # 𑢴 --> 𑣔
    charMap[0x118b4] = codePointToUTF8(0x118d4); //    # 𑢵 --> 𑣕
    charMap[0x118b5] = codePointToUTF8(0x118d5); //    # 𑢶 --> 𑣖
    charMap[0x118b6] = codePointToUTF8(0x118d6); //    # 𑢷 --> 𑣗
    charMap[0x118b7] = codePointToUTF8(0x118d7); //    # 𑢸 --> 𑣘
    charMap[0x118b8] = codePointToUTF8(0x118d8); //    # 𑢹 --> 𑣙
    charMap[0x118b9] = codePointToUTF8(0x118d9); //    # 𑢺 --> 𑣚
    charMap[0x118ba] = codePointToUTF8(0x118da); //    # 𑢻 --> 𑣛
    charMap[0x118bb] = codePointToUTF8(0x118db); //    # 𑢼 --> 𑣜
    charMap[0x118bc] = codePointToUTF8(0x118dc); //    # 𑢽 --> 𑣝
    charMap[0x118bd] = codePointToUTF8(0x118dd); //    # 𑢾 --> 𑣞
    charMap[0x118be] = codePointToUTF8(0x118de); //    # 𑢿 --> 𑣟
    charMap[0x118bf] = codePointToUTF8(0x118df); //    # 𞤀 --> 𞤢
    charMap[0x1e900] = codePointToUTF8(0x1e922); //    # 𞤁 --> 𞤣
    charMap[0x1e901] = codePointToUTF8(0x1e923); //    # 𞤂 --> 𞤤
    charMap[0x1e902] = codePointToUTF8(0x1e924); //    # 𞤃 --> 𞤥
    charMap[0x1e903] = codePointToUTF8(0x1e925); //    # 𞤄 --> 𞤦
    charMap[0x1e904] = codePointToUTF8(0x1e926); //    # 𞤅 --> 𞤧
    charMap[0x1e905] = codePointToUTF8(0x1e927); //    # 𞤆 --> 𞤨
    charMap[0x1e906] = codePointToUTF8(0x1e928); //    # 𞤇 --> 𞤩
    charMap[0x1e907] = codePointToUTF8(0x1e929); //    # 𞤈 --> 𞤪
    charMap[0x1e908] = codePointToUTF8(0x1e92a); //    # 𞤉 --> 𞤫
    charMap[0x1e909] = codePointToUTF8(0x1e92b); //    # 𞤊 --> 𞤬
    charMap[0x1e90a] = codePointToUTF8(0x1e92c); //    # 𞤋 --> 𞤭
    charMap[0x1e90b] = codePointToUTF8(0x1e92d); //    # 𞤌 --> 𞤮
    charMap[0x1e90c] = codePointToUTF8(0x1e92e); //    # 𞤍 --> 𞤯
    charMap[0x1e90d] = codePointToUTF8(0x1e92f); //    # 𞤎 --> 𞤰
    charMap[0x1e90e] = codePointToUTF8(0x1e930); //    # 𞤏 --> 𞤱
    charMap[0x1e90f] = codePointToUTF8(0x1e931); //    # 𞤐 --> 𞤲
    charMap[0x1e910] = codePointToUTF8(0x1e932); //    # 𞤑 --> 𞤳
    charMap[0x1e911] = codePointToUTF8(0x1e933); //    # 𞤒 --> 𞤴
    charMap[0x1e912] = codePointToUTF8(0x1e934); //    # 𞤓 --> 𞤵
    charMap[0x1e913] = codePointToUTF8(0x1e935); //    # 𞤔 --> 𞤶
    charMap[0x1e914] = codePointToUTF8(0x1e936); //    # 𞤕 --> 𞤷
    charMap[0x1e915] = codePointToUTF8(0x1e937); //    # 𞤖 --> 𞤸
    charMap[0x1e916] = codePointToUTF8(0x1e938); //    # 𞤗 --> 𞤹
    charMap[0x1e917] = codePointToUTF8(0x1e939); //    # 𞤘 --> 𞤺
    charMap[0x1e918] = codePointToUTF8(0x1e93a); //    # 𞤙 --> 𞤻
    charMap[0x1e919] = codePointToUTF8(0x1e93b); //    # 𞤚 --> 𞤼
    charMap[0x1e91a] = codePointToUTF8(0x1e93c); //    # 𞤛 --> 𞤽
    charMap[0x1e91b] = codePointToUTF8(0x1e93d); //    # 𞤜 --> 𞤾
    charMap[0x1e91c] = codePointToUTF8(0x1e93e); //    # 𞤝 --> 𞤿
    charMap[0x1e91d] = codePointToUTF8(0x1e93f); //    # 𞤞 --> 𞥀
    charMap[0x1e91e] = codePointToUTF8(0x1e940); //    # 𞤟 --> 𞥁
    charMap[0x1e91f] = codePointToUTF8(0x1e941); //    # 𞤠 --> 𞥂
    charMap[0x1e920] = codePointToUTF8(0x1e942); //    # 𞤡 --> 𞥃
    charMap[0x1e921] = codePointToUTF8(0x1e943); //
    return std::move(charMap);
}

#endif
